@@ -27,6 +27,7 @@
 
 #include <QPainter>
 #include <QToolTip>
+#include <QGraphicsSceneMouseEvent>
 
 AbstractClipItem::AbstractClipItem(const ItemInfo info, const QRectF& rect, double fps) :
         QObject(),
@@ -148,9 +149,6 @@ void AbstractClipItem::resizeEnd(int posx, double speed, bool /*updateKeyFrames*
     //kDebug() << "// DUR DIFF1:" << durationDiff.frames(25) << ", ADJUSTED: " << durationDiff.frames(25) * speed << ", SPED:" << speed;
     if (cropDuration() + durationDiff <= GenTime()) {
         durationDiff = GenTime() - (cropDuration() - GenTime(3, m_fps));
-    } else if (cropStart() + cropDuration() + durationDiff >= maxDuration()) {
-        //kDebug() << "// MAX OVERLOAD:" << cropDuration().frames(25) << " + " << durationDiff.frames(25) << ", MAX:" << maxDuration().frames(25);
-        durationDiff = maxDuration() - cropDuration() - cropStart();
     }
     //kDebug() << "// DUR DIFF2:" << durationDiff.frames(25) << ", ADJUSTED: " << durationDiff.frames(25) * speed << ", SPED:" << speed;
     m_cropDuration += durationDiff * speed;
@@ -172,11 +170,6 @@ void AbstractClipItem::resizeEnd(int posx, double speed, bool /*updateKeyFrames*
     }
 }
 
-GenTime AbstractClipItem::duration() const
-{
-    return m_cropDuration;
-}
-
 GenTime AbstractClipItem::startPos() const
 {
     return m_startPos;
@@ -197,11 +190,6 @@ GenTime AbstractClipItem::maxDuration() const
     return m_maxDuration;
 }
 
-void AbstractClipItem::setMaxDuration(const GenTime &max)
-{
-    m_maxDuration = max;
-}
-
 QPainterPath AbstractClipItem::upperRectPart(QRectF br)
 {
     QPainterPath roundRectPathUpper;
@@ -255,7 +243,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
 {
     if (m_keyframes.count() < 2) return;
     QRectF br = rect();
-    double maxw = br.width() / m_cropDuration.frames(m_fps);
+    double maxw = br.width() / cropDuration().frames(m_fps);
     double maxh = br.height() / 100.0 * m_keyframeFactor;
     double x1;
     double y1;
@@ -263,7 +251,8 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
     double y2;
 
     // draw line showing default value
-    if (isSelected()) {
+    bool active = isSelected() || (parentItem() && parentItem()->isSelected());
+    if (active) {
         x1 = br.x();
         x2 = br.right();
         y1 = br.bottom() - m_keyframeDefault * maxh;
@@ -280,7 +269,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
     // draw keyframes
     QMap<int, double>::const_iterator i = m_keyframes.constBegin();
     QColor color(Qt::blue);
-    x1 = br.x() + maxw * (i.key() - m_cropStart.frames(m_fps));
+    x1 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
     y1 = br.bottom() - i.value() * maxh;
     QLineF l2;
     while (i != m_keyframes.constEnd()) {
@@ -288,34 +277,34 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
         else color = QColor(Qt::blue);
         ++i;
         if (i == m_keyframes.constEnd()) break;
-        x2 = br.x() + maxw * (i.key() - m_cropStart.frames(m_fps));
+        x2 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
         y2 = br.bottom() - i.value() * maxh;
         QLineF l(x1, y1, x2, y2);
         l2 = painter->matrix().map(l);
         painter->drawLine(l2);
-        if (isSelected()) {
+        if (active) {
             painter->fillRect(l2.x1() - 3, l2.y1() - 3, 6, 6, QBrush(color));
         }
         x1 = x2;
         y1 = y2;
     }
-    if (isSelected()) painter->fillRect(l2.x2() - 3, l2.y2() - 3, 6, 6, QBrush(color));
+    if (active) painter->fillRect(l2.x2() - 3, l2.y2() - 3, 6, 6, QBrush(color));
 }
 
 int AbstractClipItem::mouseOverKeyFrames(QPointF pos)
 {
     QRectF br = sceneBoundingRect();
-    double maxw = br.width() / m_cropDuration.frames(m_fps);
+    double maxw = br.width() / cropDuration().frames(m_fps);
     double maxh = br.height() / 100.0 * m_keyframeFactor;
     if (m_keyframes.count() > 1) {
         QMap<int, double>::const_iterator i = m_keyframes.constBegin();
         double x1;
         double y1;
         while (i != m_keyframes.constEnd()) {
-            x1 = br.x() + maxw * (i.key() - m_cropStart.frames(m_fps));
+            x1 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
             y1 = br.bottom() - i.value() * maxh;
             if (qAbs(pos.x() - x1) < 6 && qAbs(pos.y() - y1) < 6) {
-                setToolTip('[' + QString::number((GenTime(i.key(), m_fps) - m_cropStart).seconds(), 'f', 2) + i18n("seconds") + ", " + QString::number(i.value(), 'f', 1) + "%]");
+                setToolTip('[' + QString::number((GenTime(i.key(), m_fps) - cropStart()).seconds(), 'f', 2) + i18n("seconds") + ", " + QString::number(i.value(), 'f', 1) + "%]");
                 return i.key();
             } else if (x1 > pos.x()) break;
             ++i;
@@ -329,11 +318,11 @@ void AbstractClipItem::updateSelectedKeyFrame()
 {
     if (m_editedKeyframe == -1) return;
     QRectF br = sceneBoundingRect();
-    double maxw = br.width() / m_cropDuration.frames(m_fps);
+    double maxw = br.width() / cropDuration().frames(m_fps);
     double maxh = br.height() / 100.0 * m_keyframeFactor;
-    update(br.x() + maxw * (m_selectedKeyframe - m_cropStart.frames(m_fps)) - 3, br.bottom() - m_keyframes[m_selectedKeyframe] * maxh - 3, 12, 12);
+    update(br.x() + maxw *(m_selectedKeyframe - cropStart().frames(m_fps)) - 3, br.bottom() - m_keyframes[m_selectedKeyframe] * maxh - 3, 12, 12);
     m_selectedKeyframe = m_editedKeyframe;
-    update(br.x() + maxw * (m_selectedKeyframe - m_cropStart.frames(m_fps)) - 3, br.bottom() - m_keyframes[m_selectedKeyframe] * maxh - 3, 12, 12);
+    update(br.x() + maxw *(m_selectedKeyframe - cropStart().frames(m_fps)) - 3, br.bottom() - m_keyframes[m_selectedKeyframe] * maxh - 3, 12, 12);
 }
 
 int AbstractClipItem::selectedKeyFramePos() const
@@ -350,8 +339,8 @@ void AbstractClipItem::updateKeyFramePos(const GenTime pos, const double value)
 {
     if (!m_keyframes.contains(m_selectedKeyframe)) return;
     int newpos = (int) pos.frames(m_fps);
-    int start = m_cropStart.frames(m_fps);
-    int end = (m_cropStart + m_cropDuration).frames(m_fps);
+    int start = cropStart().frames(m_fps);
+    int end = (cropStart() + cropDuration()).frames(m_fps);
     newpos = qMax(newpos, start);
     newpos = qMin(newpos, end);
     if (value < -50 && m_selectedKeyframe != start && m_selectedKeyframe != end) {
@@ -430,3 +419,12 @@ bool AbstractClipItem::isItemLocked() const
     return !(flags() & (QGraphicsItem::ItemIsSelectable));
 }
 
+// virtual
+void AbstractClipItem::mousePressEvent(QGraphicsSceneMouseEvent * event)
+{
+    if (event->modifiers() & Qt::ShiftModifier) {
+        // User want to do a rectangle selection, so ignore the event to pass it to the view
+        event->ignore();
+    } else QGraphicsItem::mousePressEvent(event);
+}
+
