@@ -26,6 +26,7 @@
 #include "gentime.h"
 
 class CustomTrackScene;
+class QGraphicsSceneMouseEvent;
 
 class AbstractClipItem : public QObject , public QGraphicsRectItem
 {
@@ -55,11 +56,9 @@ public:
     virtual GenTime cropDuration() const ;
     virtual void resizeStart(int posx, double speed = 1.0);
     virtual void resizeEnd(int posx, double speed = 1.0, bool updateKeyFrames = true);
-    virtual GenTime duration() const;
     virtual double fps() const;
     virtual GenTime maxDuration() const;
     virtual void setCropStart(GenTime pos);
-    virtual void setMaxDuration(const GenTime &max);
 
 protected:
     int m_track;
@@ -78,6 +77,7 @@ protected:
     //QRect visibleRect();
     void drawKeyFrames(QPainter *painter, QRectF exposedRect);
     int mouseOverKeyFrames(QPointF pos);
+    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
 };
 
 #endif
