@@ -79,7 +79,7 @@ public:
     void flashClip();
     void addTransition(Transition*);
     /** regenerate audio and video thumbnails */
-    void resetThumbs();
+    void resetThumbs(bool clearExistingThumbs);
     /** update clip properties from base clip */
     void refreshClip(bool checkDuration);
     /** Returns a list of times for this clip's markers */
@@ -112,18 +112,15 @@ public:
 
 protected:
     //virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
-    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
-    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
     virtual void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
     virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent *event);
     virtual void dropEvent(QGraphicsSceneDragDropEvent *event);
-    virtual void hoverEnterEvent(QGraphicsSceneHoverEvent *);
-    virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent *);
+    //virtual void hoverEnterEvent(QGraphicsSceneHoverEvent *);
+    //virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent *);
     virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value);
 
 private:
     DocClipBase *m_clip;
-    OPERATIONTYPE m_resizeMode;
     QString m_producer;
     CLIPTYPE m_clipType;
     QString m_clipName;
@@ -143,7 +140,7 @@ private:
     QTimeLine *m_timeLine;
     bool m_startThumbRequested;
     bool m_endThumbRequested;
-    bool m_hover;
+    //bool m_hover;
     double m_speed;
 
     EffectsList m_effectList;
@@ -157,7 +154,6 @@ private:
     QPixmap m_audioPix;
 
 private slots:
-    void slotFetchThumbs();
     void slotGetStartThumb();
     void slotGetEndThumb();
     void slotGotAudioData();
@@ -168,6 +164,7 @@ private slots:
     void slotThumbReady(int frame, QPixmap pix);
 
 public slots:
+    void slotFetchThumbs();
     void slotSetStartThumb(const QPixmap pix);
     void slotSetEndThumb(const QPixmap pix);
 
