@@ -64,7 +64,7 @@ public:
     void slotDeleteClipMarker(const QString &comment, const QString &id, const GenTime &position);
     void slotDeleteAllClipMarkers(const QString &id);
     void addMarker(const QString &id, const GenTime &pos, const QString comment);
-    void setScale(double scaleFactor);
+    void setScale(double scaleFactor, double verticalScale);
     void deleteClip(const QString &clipId);
     void slotAddEffect(QDomElement effect, GenTime pos, int track);
     void slotAddGroupEffect(QDomElement effect, AbstractGroupItem *group);
@@ -120,6 +120,8 @@ public:
     void setAudioOnly();
     void setAudioAndVideo();
     void doChangeClipType(const GenTime &pos, int track, bool videoOnly, bool audioOnly);
+    int hasGuide(int pos, int offset);
+    void reloadTransitionLumas();
 
 public slots:
     void setCursorPos(int pos, bool seek = true);
@@ -142,8 +144,8 @@ public slots:
     bool addGuide(const GenTime pos, const QString &comment);
     void slotAddGuide();
     void slotEditGuide(CommentedTime guide);
-    void slotEditGuide();
-    void slotDeleteGuide();
+    void slotEditGuide(int guidePos = -1);
+    void slotDeleteGuide(int guidePos = -1);
     void slotDeleteAllGuides();
     void editGuide(const GenTime oldPos, const GenTime pos, const QString &comment);
     void copyClip();
@@ -210,8 +212,11 @@ private:
     QAction *m_changeSpeedAction;
     QAction *m_pasteEffectsAction;
     QAction *m_ungroupAction;
+    QAction *m_editGuide;
+    QAction *m_deleteGuide;
     QActionGroup *m_clipTypeGroup;
     QTimer m_scrollTimer;
+    QTimer m_thumbsTimer;
     int m_scrollOffset;
     bool m_clipDrag;
 
@@ -225,10 +230,11 @@ private:
     QPoint m_menuPosition;
     bool m_blockRefresh;
     AbstractGroupItem *m_selectionGroup;
+    QList <ClipItem *> m_waitingThumbs;
 
     /** Get the index of the video track that is just below current track */
     int getPreviousVideoTrack(int track);
-    void updateClipFade(ClipItem * item, bool updateFadeOut = false);
+    void updateClipFade(ClipItem * item);
     bool canBePastedTo(ItemInfo info, int type) const;
     bool canBePasted(QList<AbstractClipItem *> items, GenTime offset, int trackOffset) const;
     bool canBeMoved(QList<AbstractClipItem *> items, GenTime offset, int trackOffset) const;
@@ -247,6 +253,9 @@ private slots:
     void slotRefreshGuides();
     void slotEnableRefresh();
     void slotCheckMouseScrolling();
+    void slotEditTimeLineGuide();
+    void slotDeleteTimeLineGuide();
+    void slotFetchNextThumbs();
 
 signals:
     void cursorMoved(int, int);
@@ -254,7 +263,7 @@ signals:
     void zoomOut();
     void mousePosition(int);
     void clipItemSelected(ClipItem*, int ix = -1);
-    void transitionItemSelected(Transition*, bool update = false);
+    void transitionItemSelected(Transition*, int track = 0, QPoint p = QPoint(), bool update = false);
     void activateDocumentMonitor();
     void trackHeightChanged();
     void displayMessage(const QString, MessageType);
