@@ -21,10 +21,10 @@
 #ifndef DEFINITIONS_H
 #define DEFINITIONS_H
 
-#include <KLocale>
-
 #include "gentime.h"
 
+#include <KLocale>
+
 const int FRAME_SIZE = 90;
 const int MAXCLIPDURATION = 15000;
 
@@ -47,7 +47,8 @@ enum MessageType {
     DefaultMessage,
     OperationCompletedMessage,
     InformationMessage,
-    ErrorMessage
+    ErrorMessage,
+    MltError
 };
 
 enum TRACKTYPE { AUDIOTRACK = 0, VIDEOTRACK = 1 };
@@ -179,4 +180,6 @@ private:
 
 
 };
+
+
 #endif
