@@ -56,7 +56,7 @@ Q_OBJECT public:
      *   done here. If a new clip type is added then it should be possible to combine it with both audio
      *   and video. */
 
-    DocClipBase(ClipManager *clipManager, QDomElement xml, const QString &id, bool placeHolder = false);
+    DocClipBase(ClipManager *clipManager, QDomElement xml, const QString &id);
 //    DocClipBase & operator=(const DocClipBase & clip);
     virtual ~ DocClipBase();
 
@@ -110,7 +110,7 @@ Q_OBJECT public:
     }
 
     /** Sets producers for the current clip (one for each track due to a limitation in MLT's track mixing */
-    void setProducer(Mlt::Producer *producer);
+    void setProducer(Mlt::Producer *producer, bool reset = false);
     /** Retrieve a producer for a track */
     Mlt::Producer *producer(int track = -1);
     /** Retrieve the producer that shows only video */
@@ -182,6 +182,7 @@ Q_OBJECT public:
 
     /** Returns true is clip is missing but user wants to keep it as placeholder */
     bool isPlaceHolder() const;
+    static QString getHash(const QString &path);
 
 private:   // Private attributes
 
@@ -219,6 +220,7 @@ private:   // Private attributes
     void slotCreateAudioTimer();
     void slotRefreshProducer();
     void setProducerProperty(const char *name, int data);
+    void setProducerProperty(const char *name, double data);
     void getFileHash(const QString url);
 
 public slots:
