@@ -33,8 +33,9 @@
 
 #include "dvdwizardvob.h"
 #include "dvdwizardmenu.h"
-#include "ui_dvdwizardiso_ui.h"
+#include "dvdwizardchapters.h"
 #include "ui_dvdwizardstatus_ui.h"
+#include "ui_dvdwizardchapters_ui.h"
 
 class DvdWizard : public QWizard
 {
@@ -46,20 +47,29 @@ public:
 private:
     DvdWizardVob *m_pageVob;
     DvdWizardMenu *m_pageMenu;
-    Ui::DvdWizardIso_UI m_iso;
     Ui::DvdWizardStatus_UI m_status;
+    DvdWizardChapters *m_pageChapters;
     KTemporaryFile m_menuFile;
     KTemporaryFile m_authorFile;
     QProcess *m_dvdauthor;
     QProcess *m_mkiso;
     QString m_creationLog;
     void cleanup();
+    QMenu *m_burnMenu;
 
 private slots:
     void slotPageChanged(int page);
     void slotRenderFinished(int exitCode, QProcess::ExitStatus status);
     void slotIsoFinished(int exitCode, QProcess::ExitStatus status);
     void generateDvd();
+    void slotPreview();
+    void slotBurn();
+    void slotGenerate();
+    void slotAbort();
+    void slotLoad();
+    void slotSave();
+    void slotShowRenderInfo();
+    void slotShowIsoInfo();
 };
 
 #endif
