@@ -48,7 +48,7 @@ EffectStackView::EffectStackView(QWidget *parent) :
     m_ui.buttonUp->setToolTip(i18n("Move effect up"));
     m_ui.buttonDown->setIcon(KIcon("go-down"));
     m_ui.buttonDown->setToolTip(i18n("Move effect down"));
-    m_ui.buttonDel->setIcon(KIcon("trash-empty"));
+    m_ui.buttonDel->setIcon(KIcon("edit-delete"));
     m_ui.buttonDel->setToolTip(i18n("Delete effect"));
     m_ui.buttonSave->setIcon(KIcon("document-save"));
     m_ui.buttonSave->setToolTip(i18n("Save effect"));
@@ -167,7 +167,7 @@ void EffectStackView::setupListView(int ix)
     KIcon audioIcon("kdenlive-show-audio");
     QListWidgetItem* item;
 
-    for (int i = 0;i < m_clipref->effectsCount();i++) {
+    for (int i = 0; i < m_clipref->effectsCount(); i++) {
         QDomElement d = m_clipref->effectAt(i);
 
         QDomNode namenode = d.elementsByTagName("name").item(0);
