@@ -28,6 +28,7 @@
 #include "ui_geometryval_ui.h"
 #include "definitions.h"
 #include "keyframehelper.h"
+#include "ui_geometryposition_ui.h"
 
 //class QGraphicsScene;
 class GraphicsSceneRectMove;
@@ -39,8 +40,9 @@ class Geometryval : public QWidget
 {
     Q_OBJECT
 public:
-    explicit Geometryval(const MltVideoProfile profile, QWidget* parent = 0);
+    explicit Geometryval(const MltVideoProfile profile, QPoint frame_size, QWidget* parent = 0);
     QDomElement getParamDesc();
+    void setFrameSize(QPoint p);
 
 private:
     Ui::Geometryval m_ui;
@@ -56,7 +58,9 @@ private:
     QMenu *m_alignMenu;
     QAction *m_syncAction;
     bool m_fixedMode;
+    QPoint m_frameSize;
     void updateTransitionPath();
+    Ui::GeometryPosition_UI *m_view;
 
 public slots:
     void setupParam(const QDomElement&, int, int);
@@ -73,6 +77,7 @@ private slots:
     void slotResize100();
     void slotResize200();
     void slotResizeCustom();
+    void slotResizeOriginal();
     void slotAlignRight();
     void slotAlignLeft();
     void slotAlignTop();
@@ -81,6 +86,8 @@ private slots:
     void slotAlignHCenter();
     void slotAlignVCenter();
     void slotSyncCursor();
+    void slotGeometry();
+    void slotResetPosition();
 
 signals:
     void parameterChanged();
