@@ -19,7 +19,6 @@
 
 
 #include "headertrack.h"
-#include "kdenlivesettings.h"
 
 #include <KIcon>
 #include <KLocale>
@@ -30,14 +29,15 @@
 #include <QPainter>
 #include <QAction>
 
-HeaderTrack::HeaderTrack(int index, TrackInfo info, QWidget *parent) :
+HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, QWidget *parent) :
         QWidget(parent),
         m_index(index),
         m_type(info.type)
 {
-    setFixedHeight(KdenliveSettings::trackheight());
+    setFixedHeight(height);
     m_view.setupUi(this);
     m_view.track_number->setText(QString::number(m_index));
+
     m_view.buttonVideo->setChecked(!info.isBlind);
     m_view.buttonVideo->setToolTip(i18n("Hide track"));
     m_view.buttonAudio->setChecked(!info.isMute);
@@ -63,24 +63,40 @@ HeaderTrack::HeaderTrack(int index, TrackInfo info, QWidget *parent) :
     connect(m_view.buttonAudio, SIGNAL(clicked()), this, SLOT(switchAudio()));
     connect(m_view.buttonLock, SIGNAL(clicked()), this, SLOT(switchLock()));
 
-    m_contextMenu = new QMenu(this);
+    // Don't show track buttons if size is too small
+    if (height < 40) {
+        m_view.buttonVideo->setHidden(true);
+        m_view.buttonAudio->setHidden(true);
+        m_view.buttonLock->setHidden(true);
+        //m_view.horizontalSpacer;
+    }
 
+    setContextMenuPolicy(Qt::ActionsContextMenu);
     QAction *insertAction = new QAction(i18n("Insert Track"), this);
-    m_contextMenu->addAction(insertAction);
+    addAction(insertAction);
     connect(insertAction, SIGNAL(triggered()), this, SLOT(slotAddTrack()));
 
     QAction *removeAction = new QAction(KIcon("edit-delete"), i18n("Delete Track"), this);
-    m_contextMenu->addAction(removeAction);
+    addAction(removeAction);
     connect(removeAction, SIGNAL(triggered()), this, SLOT(slotDeleteTrack()));
 
     QAction *changeAction = new QAction(i18n("Change Track Type"), this);
-    m_contextMenu->addAction(changeAction);
+    addAction(changeAction);
     connect(changeAction, SIGNAL(triggered()), this, SLOT(slotChangeTrack()));
 }
 
 HeaderTrack::~HeaderTrack()
 {
-    delete m_contextMenu;
+}
+
+void HeaderTrack::adjustSize(int height)
+{
+    // Don't show track buttons if size is too small
+    bool smallTracks = height < 40;
+    if (m_type == VIDEOTRACK) m_view.buttonVideo->setHidden(smallTracks);
+    m_view.buttonAudio->setHidden(smallTracks);
+    m_view.buttonLock->setHidden(smallTracks);
+    setFixedHeight(height);
 }
 
 void HeaderTrack::switchVideo()
@@ -135,11 +151,6 @@ void HeaderTrack::slotChangeTrack()
     emit changeTrack(m_index);
 }
 
-// virtual
-void HeaderTrack::contextMenuEvent(QContextMenuEvent * event)
-{
-    m_contextMenu->popup(event->globalPos());
-}
 
 // virtual
 /*void HeaderTrack::paintEvent(QPaintEvent *e) {
