@@ -31,19 +31,15 @@ class HeaderTrack : public QWidget
     Q_OBJECT
 
 public:
-    HeaderTrack(int index, TrackInfo info, QWidget *parent = 0);
+    HeaderTrack(int index, TrackInfo info, int height, QWidget *parent = 0);
     ~HeaderTrack();
     void setLock(bool lock);
-
-protected:
-    //virtual void paintEvent(QPaintEvent * /*e*/);
-    virtual void contextMenuEvent(QContextMenuEvent * event);
+    void adjustSize(int height);
 
 private:
     int m_index;
     TRACKTYPE m_type;
     Ui::TrackHeader_UI m_view;
-    QMenu *m_contextMenu;
 
 private slots:
     void switchAudio();
