@@ -49,7 +49,7 @@ class KdenliveDoc: public QObject
 {
 Q_OBJECT public:
 
-    KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, const QString &profileName, const QPoint tracks, Render *render, MainWindow *parent = 0);
+    KdenliveDoc(const KUrl &url, const KUrl &projectFolder, QUndoGroup *undoGroup, QString profileName, const QPoint tracks, Render *render, MainWindow *parent = 0);
     ~KdenliveDoc();
     QDomNodeList producersList();
     double fps() const;
@@ -90,8 +90,8 @@ Q_OBJECT public:
     /** Used to inform main app of the current document loading progress */
     void loadingProgressed();
     void syncGuides(QList <Guide *> guides);
-    void setZoom(int factor);
-    int zoom() const;
+    void setZoom(int horizontal, int vertical);
+    QPoint zoom() const;
     double dar();
     double projectDuration() const;
     bool saveSceneList(const QString &path, const QString &scene);
@@ -110,17 +110,16 @@ Q_OBJECT public:
     QString getLadspaFile() const;
     void setZone(int start, int end);
     QPoint zone() const;
-    void setSceneList();
+    int setSceneList();
     void updatePreviewSettings();
     bool isTrackLocked(int ix) const;
+    void setDocumentProperty(const QString &name, const QString &value);
+    const QString getDocumentProperty(const QString &name) const;
 
 private:
     KUrl m_url;
     QDomDocument m_document;
     double m_fps;
-    int m_zoom;
-    /** Cursor position at document opening */
-    int m_startPos;
     int m_width;
     int m_height;
     Timecode m_timecode;
@@ -130,28 +129,29 @@ private:
     MltVideoProfile m_profile;
     QTimer *m_autoSaveTimer;
     QString m_searchFolder;
-    /** tells whether current doc has been changed since last save event */
+    /** tells whether current doc has been changed since last save event */
     bool m_modified;
     /** Project folder, used to store project files (titles, effects,...) */
     KUrl m_projectFolder;
     double m_documentLoadingStep;
     double m_documentLoadingProgress;
     bool m_abortLoading;
-    int m_zoneStart;
-    int m_zoneEnd;
+    QMap <QString, QString> m_documentProperties;
 
     QList <TrackInfo> m_tracksList;
 
-    bool convertDocument(double version);
     QDomDocument createEmptyDocument(const int videotracks, const int audiotracks);
-    QString colorToString(const QColor& c);
 
     void setNewClipResource(const QString &id, const QString &path);
     QString searchFileRecursively(const QDir &dir, const QString &matchSize, const QString &matchHash) const;
     void moveProjectData(KUrl url);
+    bool checkDocumentClips(QDomNodeList infoproducers);
 
 public slots:
-    void slotCreateTextClip(QString group, const QString &groupId);
+    void slotCreateColorClip(const QString &name, const QString &color, const QString &duration, QString group, const QString &groupId);
+    void slotCreateSlideshowClipFile(const QString name, const QString path, int count, const QString duration, const bool loop, const bool fade, const QString &luma_duration, const QString &luma_file, const int softness, QString group, const QString &groupId);
+    void slotCreateTextClip(QString group, const QString &groupId, const QString &templatePath = QString());
+    void slotCreateTextTemplateClip(QString group, const QString &groupId, KUrl path);
     /** Set to true if document needs saving, false otherwise */
     void setModified(bool mod = true);
     void checkProjectClips();
@@ -166,7 +166,7 @@ signals:
     void updateClipDisplay(const QString&);
     void deleteTimelineClip(const QString&);
     void progressInfo(const QString &, int);
-    /** emitted when the document state has been modified (= needs saving or not) */
+    /** emitted when the document state has been modified (= needs saving or not) */
     void docModified(bool);
     void selectLastAddedClip(const QString &);
     void guidesUpdated();
