@@ -27,9 +27,11 @@
 #include <KConfigDialogManager>
 #include <kde_file.h>
 #include <KIO/NetAccess>
+#include <kdeversion.h>
 
 #include <QDir>
 #include <QTimer>
+#include <QTreeWidgetItem>
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -41,7 +43,8 @@
 
 
 KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
-        KConfigDialog(parent, "settings", KdenliveSettings::self())
+        KConfigDialog(parent, "settings", KdenliveSettings::self()),
+        m_modified(false)
 {
 
     QWidget *p1 = new QWidget;
@@ -66,11 +69,11 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
     m_configEnv.projecturl->lineEdit()->setObjectName("kcfg_defaultprojectfolder");
     m_configEnv.capturefolderurl->setMode(KFile::Directory);
     m_configEnv.capturefolderurl->lineEdit()->setObjectName("kcfg_capturefolder");
-    m_page2 = addPage(p2, i18n("Environment"), "terminal");
+    m_page2 = addPage(p2, i18n("Environment"), "application-x-executable-script");
 
     QWidget *p4 = new QWidget;
     m_configCapture.setupUi(p4);
-    m_page4 = addPage(p4, i18n("Capture"), "audio-card");
+    m_page4 = addPage(p4, i18n("Capture"), "media-record");
     m_configCapture.tabWidget->setCurrentIndex(KdenliveSettings::defaultcapture());
 
     QWidget *p5 = new QWidget;
@@ -88,7 +91,14 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
 
     QWidget *p6 = new QWidget;
     m_configSdl.setupUi(p6);
-    m_page6 = addPage(p6, i18n("Playback"), "audio-card");
+    m_page6 = addPage(p6, i18n("Playback"), "media-playback-start");
+
+    QWidget *p7 = new QWidget;
+    m_configTranscode.setupUi(p7);
+    m_page7 = addPage(p7, i18n("Transcode"), "edit-copy");
+    connect(m_configTranscode.button_add, SIGNAL(clicked()), this, SLOT(slotAddTranscode()));
+    connect(m_configTranscode.button_delete, SIGNAL(clicked()), this, SLOT(slotDeleteTranscode()));
+    connect(m_configTranscode.profiles_list, SIGNAL(itemChanged(QTreeWidgetItem *, int)), this, SLOT(slotDialogModified()));
 
     QStringList actions;
     actions << i18n("Do nothing");
@@ -125,6 +135,7 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(QWidget * parent) :
     connect(m_configCapture.kcfg_rmd_capture_type, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateRmdRegionStatus()));
 
     slotUpdateRmdRegionStatus();
+    loadTranscodeProfiles();
 
 
     //HACK: check dvgrab version, because only dvgrab >= 3.3 supports
@@ -204,7 +215,7 @@ void KdenliveSettingsDialog::initDevices()
     m_configSdl.kcfg_audio_driver->addItem(i18n("ARTS daemon"), "artsc");
 
     if (!KdenliveSettings::audiodrivername().isEmpty())
-        for (int i = 1;i < m_configSdl.kcfg_audio_driver->count(); i++) {
+        for (int i = 1; i < m_configSdl.kcfg_audio_driver->count(); i++) {
             if (m_configSdl.kcfg_audio_driver->itemData(i).toString() == KdenliveSettings::audiodrivername()) {
                 m_configSdl.kcfg_audio_driver->setCurrentIndex(i);
                 KdenliveSettings::setAudio_driver((uint) i);
@@ -303,7 +314,14 @@ void KdenliveSettingsDialog::showPage(int page, int option)
     case 5:
         setCurrentPage(m_page5);
         break;
-
+    case 6:
+        setCurrentPage(m_page6);
+        break;
+    case 7:
+        setCurrentPage(m_page7);
+        break;
+    default:
+        setCurrentPage(m_page1);
     }
 }
 
@@ -383,7 +401,8 @@ void KdenliveSettingsDialog::rebuildVideo4Commands()
 
 void KdenliveSettingsDialog::updateSettings()
 {
-    kDebug() << "// // // KCONFIG UPDATE called";
+    //kDebug() << "// // // KCONFIG UPDATE called";
+
     m_defaultProfile = m_configMisc.kcfg_profiles_list->currentText();
     KdenliveSettings::setDefault_profile(m_defaultPath);
 
@@ -437,7 +456,17 @@ void KdenliveSettingsDialog::updateSettings()
         updatePreview = true;
     }
 
-    KConfigDialog::updateSettings();
+    if (m_modified) {
+        // The transcoding profiles were modified, save.
+        m_modified = false;
+        saveTranscodeProfiles();
+    }
+
+#if KDE_IS_VERSION(4,3,0)
+    KConfigDialog::settingsChangedSlot();
+#endif
+
+    //KConfigDialog::updateSettings();
     if (resetProfile) emit doResetProfile();
     if (updatePreview) emit updatePreviewSettings();
 }
@@ -462,6 +491,71 @@ void KdenliveSettingsDialog::slotCheckAlsaDriver()
     m_configSdl.kcfg_audio_device->setEnabled(value == "alsa");
 }
 
+void KdenliveSettingsDialog::loadTranscodeProfiles()
+{
+    KSharedConfigPtr config = KSharedConfig::openConfig("kdenlivetranscodingrc");
+    KConfigGroup transConfig(config, "Transcoding");
+    // read the entries
+    m_configTranscode.profiles_list->blockSignals(true);
+    QMap< QString, QString > profiles = transConfig.entryMap();
+    QMapIterator<QString, QString> i(profiles);
+    while (i.hasNext()) {
+        i.next();
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_configTranscode.profiles_list, QStringList() << i.key() << i.value());
+        item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable);
+    }
+    m_configTranscode.profiles_list->blockSignals(false);
+}
+
+void KdenliveSettingsDialog::saveTranscodeProfiles()
+{
+    KSharedConfigPtr config = KSharedConfig::openConfig("kdenlivetranscodingrc");
+    //KSharedConfigPtr config = KGlobal::config();
+    KConfigGroup transConfig(config, "Transcoding");
+    // read the entries
+    transConfig.deleteGroup();
+    int max = m_configTranscode.profiles_list->topLevelItemCount();
+    for (int i = 0; i < max; i++) {
+        QTreeWidgetItem *item = m_configTranscode.profiles_list->topLevelItem(i);
+        transConfig.writeEntry(item->text(0), item->text(1));
+    }
+    config->sync();
+}
+
+void KdenliveSettingsDialog::slotAddTranscode()
+{
+    QTreeWidgetItem *item = new QTreeWidgetItem(m_configTranscode.profiles_list, QStringList() << i18n("Name") << i18n("Parameters"));
+    item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsEditable);
+    m_configTranscode.profiles_list->setCurrentItem(item);
+    m_configTranscode.profiles_list->editItem(item);
+    slotDialogModified();
+}
+
+void KdenliveSettingsDialog::slotDeleteTranscode()
+{
+    QTreeWidgetItem *item = m_configTranscode.profiles_list->currentItem();
+    if (item == NULL) return;
+    delete item;
+    slotDialogModified();
+}
+
+void KdenliveSettingsDialog::slotDialogModified()
+{
+    m_modified = true;
+#if KDE_IS_VERSION(4,3,0)
+    KConfigDialog::updateButtons();
+#endif
+}
+
+//virtual
+bool KdenliveSettingsDialog::hasChanged()
+{
+    if (m_modified) return true;
+    return KConfigDialog::hasChanged();
+}
+
+
+
 #include "kdenlivesettingsdialog.moc"
 
 
