@@ -93,14 +93,14 @@ protected:
      * This function is called when it is time for the app to save its
      * properties for session management purposes.
      */
-    void saveProperties(KConfig *);
+    virtual void saveProperties(KConfigGroup &config);
 
     /**
      * This function is called when this app is restored.  The KConfig
      * object points to the session management config file that was saved
      * with @ref saveProperties
      */
-    void readProperties(KConfig *);
+    virtual void readProperties(const KConfigGroup &config);
 
 private:
     KTabWidget* m_timelineArea;
@@ -192,6 +192,8 @@ private:
     void aboutPlugins();
     QStringList m_pluginFileNames;
     QByteArray m_timelineState;
+    void loadTranscoders();
+
 
 public slots:
     void openFile(const KUrl &url);
@@ -217,6 +219,7 @@ private slots:
     void slotUpdateMousePosition(int pos);
     void slotAddEffect(QDomElement effect, GenTime pos = GenTime(), int track = -1);
     void slotEditProfiles();
+    void slotDetectAudioDriver();
     void slotEditProjectSettings();
     void slotDisplayActionMessage(QAction *a);
     void slotSwitchVideoThumbs();
@@ -224,7 +227,6 @@ private slots:
     void slotSwitchMarkersComments();
     void slotSwitchSnap();
     void slotRenderProject();
-    void slotDoRender(const QString &dest, const QString &render, const QStringList &overlay_args, const QStringList &avformat_args, bool zoneOnly, bool playAfter, double guideStart, double guideEnd, bool resizeProfile, const QString &scriptExport);
     void slotFullScreen();
     void slotUpdateDocumentState(bool modified);
     void slotZoomIn();
@@ -297,6 +299,10 @@ private slots:
     void slotUpdateClipType(QAction *action);
     void slotShowTimeline(bool show);
     void slotMaximizeCurrent(bool show);
+    void slotTranscode(KUrl::List urls = KUrl::List());
+    void slotTranscodeClip();
+    void slotSetDocumentRenderProfile(const QString &dest, const QString &name, const QString &file);
+    void slotPrepareRendering(bool scriptExport, bool zoneOnly, const QString &chapterFile);
 
 signals:
     Q_SCRIPTABLE void abortRenderJob(const QString &url);
