@@ -43,16 +43,18 @@
 Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
         QWidget(parent),
         render(NULL),
-        m_monitorManager(manager),
         m_name(name),
-        m_isActive(false),
+        m_monitorManager(manager),
         m_currentClip(NULL),
-        m_dragStarted(false),
-        m_overlay(NULL)
+        m_ruler(new SmallRuler()),
+        m_overlay(NULL),
+        m_isActive(false),
+        m_scale(1),
+        m_length(0),
+        m_position(-1),
+        m_dragStarted(false)
 {
     m_ui.setupUi(this);
-    m_scale = 1;
-    m_ruler = new SmallRuler();
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_ruler);
@@ -66,8 +68,10 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
     m_playIcon = KIcon("media-playback-start");
     m_pauseIcon = KIcon("media-playback-pause");
 
-    toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
-    toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
+    if (name != "chapter") {
+        toolbar->addAction(KIcon("kdenlive-zone-start"), i18n("Set zone start"), this, SLOT(slotSetZoneStart()));
+        toolbar->addAction(KIcon("kdenlive-zone-end"), i18n("Set zone end"), this, SLOT(slotSetZoneEnd()));
+    } else m_ruler->setZone(-3, -2);
 
     toolbar->addAction(KIcon("media-seek-backward"), i18n("Rewind"), this, SLOT(slotRewind()));
     toolbar->addAction(KIcon("media-skip-backward"), i18n("Rewind 1 frame"), this, SLOT(slotRewindOneFrame()));
@@ -87,12 +91,16 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
 
     playButton->setDefaultAction(m_playAction);
 
-    QToolButton *configButton = new QToolButton(toolbar);
-    m_configMenu = new QMenu(i18n("Misc..."), this);
-    configButton->setIcon(KIcon("system-run"));
-    configButton->setMenu(m_configMenu);
-    configButton->setPopupMode(QToolButton::QToolButton::InstantPopup);
-    toolbar->addWidget(configButton);
+    if (name != "chapter") {
+        QToolButton *configButton = new QToolButton(toolbar);
+        m_configMenu = new QMenu(i18n("Misc..."), this);
+        configButton->setIcon(KIcon("system-run"));
+        configButton->setMenu(m_configMenu);
+        configButton->setPopupMode(QToolButton::QToolButton::InstantPopup);
+        toolbar->addWidget(configButton);
+        m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (100%)"), this, SLOT(slotSetSizeOneToOne()));
+        m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (50%)"), this, SLOT(slotSetSizeOneToTwo()));
+    }
 
     QWidget *spacer = new QWidget(this);
     spacer->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
@@ -122,12 +130,9 @@ Monitor::Monitor(QString name, MonitorManager *manager, QWidget *parent) :
     connect(render, SIGNAL(durationChanged(int)), this, SLOT(adjustRulerSize(int)));
     connect(render, SIGNAL(rendererPosition(int)), this, SLOT(seekCursor(int)));
     connect(render, SIGNAL(rendererStopped(int)), this, SLOT(rendererStopped(int)));
+    connect(render, SIGNAL(blockMonitors()), this, SIGNAL(blockMonitors()));
 
-    m_configMenu->addSeparator();
-    m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (100%)"), this, SLOT(slotSetSizeOneToOne()));
-    m_configMenu->addAction(KIcon("transform-scale"), i18n("Resize (50%)"), this, SLOT(slotSetSizeOneToTwo()));
     //render->createVideoXWindow(m_ui.video_frame->winId(), -1);
-    m_length = 0;
 
     if (name != "clip") {
         connect(render, SIGNAL(rendererPosition(int)), this, SIGNAL(renderPosition(int)));
@@ -182,7 +187,14 @@ void Monitor::setupMenu(QMenu *goMenu, QAction *playZone, QAction *loopZone, QMe
     showTips->setCheckable(true);
     connect(showTips, SIGNAL(toggled(bool)), this, SLOT(slotSwitchMonitorInfo(bool)));
     showTips->setChecked(KdenliveSettings::displayMonitorInfo());
+
+    QAction *dropFrames = m_contextMenu->addAction(KIcon(), i18n("Real time (drop frames)"));
+    dropFrames->setCheckable(true);
+    dropFrames->setChecked(true);
+    connect(dropFrames, SIGNAL(toggled(bool)), this, SLOT(slotSwitchDropFrames(bool)));
+
     m_configMenu->addAction(showTips);
+    m_configMenu->addAction(dropFrames);
 
 }
 
@@ -421,7 +433,7 @@ void Monitor::slotExtractCurrentFrame()
     QPixmap frame = render->extractFrame(m_position);
     QString outputFile = KFileDialog::getSaveFileName(KUrl(), "image/png");
     if (!outputFile.isEmpty()) {
-        if (QFile::exists(outputFile) && KMessageBox::questionYesNo(this, i18n("File already exists.\nDo you want to overwrite it ?")) == KMessageBox::No) return;
+        if (QFile::exists(outputFile) && KMessageBox::questionYesNo(this, i18n("File already exists.\nDo you want to overwrite it?")) == KMessageBox::No) return;
         frame.save(outputFile);
     }
 }
@@ -436,6 +448,12 @@ void Monitor::activateMonitor()
     if (!m_isActive) m_monitorManager->switchMonitors(); //m_monitorManager->activateMonitor(m_name);
 }
 
+void Monitor::setTimePos(const QString &pos)
+{
+    m_timePos->setText(pos);
+    slotSeek();
+}
+
 void Monitor::slotSeek()
 {
     const int frames = m_monitorManager->timecode().getFrameCount(m_timePos->text(), m_monitorManager->timecode().fps());
@@ -447,10 +465,8 @@ void Monitor::slotSeek(int pos)
     activateMonitor();
     if (render == NULL) return;
     m_position = pos;
-    checkOverlay();
     render->seekToFrame(pos);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
 void Monitor::checkOverlay()
@@ -475,7 +491,6 @@ void Monitor::slotStart()
     m_position = 0;
     render->seekToFrame(m_position);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
 void Monitor::slotEnd()
@@ -485,7 +500,6 @@ void Monitor::slotEnd()
     m_position = render->getLength();
     render->seekToFrame(m_position);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
 void Monitor::slotZoneStart()
@@ -495,7 +509,6 @@ void Monitor::slotZoneStart()
     m_position = m_ruler->zone().x();
     render->seekToFrame(m_position);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
 void Monitor::slotZoneEnd()
@@ -505,7 +518,6 @@ void Monitor::slotZoneEnd()
     m_position = m_ruler->zone().y();
     render->seekToFrame(m_position);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
 }
 
 void Monitor::slotRewind(double speed)
@@ -537,12 +549,14 @@ void Monitor::slotRewindOneFrame(int diff)
     activateMonitor();
     render->play(0);
     if (m_position < 1) return;
-    m_position -= diff;
-    m_position = qMax(m_position, 0);
+    /*
+     * freebsd needs this hack to upgrade m_position value:
+     * http://www.kdenlive.org/mantis/view.php?id=491
+     */
+    int position = m_position - diff;
+    m_position = qMax(position, 0);
     render->seekToFrame(m_position);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
-    checkOverlay();
 }
 
 void Monitor::slotForwardOneFrame(int diff)
@@ -554,8 +568,6 @@ void Monitor::slotForwardOneFrame(int diff)
     m_position = qMin(m_position, m_length);
     render->seekToFrame(m_position);
     emit renderPosition(m_position);
-    m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(m_position));
-    checkOverlay();
 }
 
 void Monitor::seekCursor(int pos)
@@ -569,10 +581,16 @@ void Monitor::seekCursor(int pos)
 
 void Monitor::rendererStopped(int pos)
 {
-    //int rulerPos = (int)(pos * m_scale);
+    if (m_currentClip != NULL && m_playAction->isChecked()) {
+        // Clip monitor
+        if (pos >= m_length - 1) {
+            slotStart();
+            return;
+        }
+    }
     m_ruler->slotNewValue(pos);
     m_position = pos;
-    //checkOverlay();
+    checkOverlay();
     m_timePos->setText(m_monitorManager->timecode().getTimecodeFromFrames(pos));
     m_playAction->setChecked(false);
     m_playAction->setIcon(m_playIcon);
@@ -677,7 +695,10 @@ void Monitor::slotSetXml(DocClipBase *clip, const int position)
     }
     if (clip != m_currentClip) {
         m_currentClip = clip;
-        render->setProducer(clip->producer(), position);
+        if (render->setProducer(clip->producer(), position) == -1) {
+            // MLT CONSUMER is broken
+            emit blockMonitors();
+        }
         m_position = position;
     } else if (position != -1) render->seek(GenTime(position, render->fps()));
 }
@@ -687,10 +708,10 @@ void Monitor::slotOpenFile(const QString &file)
     if (render == NULL) return;
     activateMonitor();
     QDomDocument doc;
-    QDomElement westley = doc.createElement("westley");
-    doc.appendChild(westley);
+    QDomElement mlt = doc.createElement("mlt");
+    doc.appendChild(mlt);
     QDomElement prod = doc.createElement("producer");
-    westley.appendChild(prod);
+    mlt.appendChild(prod);
     prod.setAttribute("mlt_service", "avformat");
     prod.setAttribute("resource", file);
     render->setSceneList(doc, 0);
@@ -730,6 +751,11 @@ void Monitor::setClipZone(QPoint pos)
     m_currentClip->setZone(pos);
 }
 
+void Monitor::slotSwitchDropFrames(bool show)
+{
+    render->setDropFrames(show);
+}
+
 void Monitor::slotSwitchMonitorInfo(bool show)
 {
     KdenliveSettings::setDisplayMonitorInfo(show);
@@ -744,12 +770,14 @@ void Monitor::slotSwitchMonitorInfo(bool show)
     }
 }
 
+
 MonitorRefresh::MonitorRefresh(QWidget* parent) : \
         QWidget(parent),
         m_renderer(NULL)
 {
     setAttribute(Qt::WA_PaintOnScreen);
-    setAttribute(Qt::WA_OpaquePaintEvent); //setAttribute(Qt::WA_NoSystemBackground);
+    setAttribute(Qt::WA_OpaquePaintEvent);
+    //setAttribute(Qt::WA_NoSystemBackground);
 }
 
 void MonitorRefresh::setRenderer(Render* render)
