@@ -93,25 +93,25 @@ protected:
 
 private:
     Ui::Monitor_UI m_ui;
-    MonitorManager *m_monitorManager;
-    MonitorRefresh *m_monitorRefresh;
     QString m_name;
+    MonitorManager *m_monitorManager;
+    DocClipBase *m_currentClip;
+    SmallRuler *m_ruler;
+    Overlay *m_overlay;
+    bool m_isActive;
     double m_scale;
     int m_length;
     int m_position;
-    SmallRuler *m_ruler;
+    bool m_dragStarted;
+    MonitorRefresh *m_monitorRefresh;
     KIcon m_playIcon;
     KIcon m_pauseIcon;
-    bool m_isActive;
     KRestrictedLine *m_timePos;
     QAction *m_playAction;
     QMenu *m_contextMenu;
     QMenu *m_configMenu;
     QMenu *m_playMenu;
-    DocClipBase *m_currentClip;
     QPoint m_DragStartPosition;
-    bool m_dragStarted;
-    Overlay *m_overlay;
     GenTime getSnapForPos(bool previous);
 
 private slots:
@@ -125,12 +125,13 @@ private slots:
     void slotSeek();
     void setClipZone(QPoint pos);
     void slotSwitchMonitorInfo(bool show);
+    void slotSwitchDropFrames(bool show);
 
 public slots:
     void slotOpenFile(const QString &);
     void slotSetXml(DocClipBase *clip, const int position = -1);
     void initMonitor();
-    void refreshMonitor(bool visible);
+    void refreshMonitor(bool visible = true);
     void slotSeek(int pos);
     void stop();
     void start();
@@ -153,6 +154,7 @@ public slots:
     void slotSeekToNextSnap();
     void slotSeekToPreviousSnap();
     void adjustRulerSize(int length);
+    void setTimePos(const QString &pos);
 
 signals:
     void renderPosition(int);
@@ -161,6 +163,7 @@ signals:
     void adjustMonitorSize();
     void zoneUpdated(QPoint);
     void saveZone(Render *, QPoint);
+    void blockMonitors();
 };
 
 #endif
