@@ -198,9 +198,9 @@ MltVideoProfile ProfilesDialog::getVideoProfile(QString name)
     if (!isCustom) {
         // List the Mlt profiles
         profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
-        if (profilesFiles.contains(name)) path = KdenliveSettings::mltpath() + '/' + name;
+        if (profilesFiles.contains(name)) path = KdenliveSettings::mltpath() + name;
     }
-    if (isCustom  || path.isEmpty()) {
+    if (isCustom || path.isEmpty()) {
         path = name;
     }
 
@@ -210,8 +210,8 @@ MltVideoProfile ProfilesDialog::getVideoProfile(QString name)
             return result;
         }
         if (name == KdenliveSettings::default_profile()) KdenliveSettings::setDefault_profile("dv_pal");
-        kDebug() << "// WARNING, COULD NOT FIND PROFILE " << name;
-        return getVideoProfile("dv_pal");
+        kDebug() << "// WARNING, COULD NOT FIND PROFILE " << name;
+        return result;
     }
     KConfig confFile(path, KConfig::SimpleConfig);
     result.path = name;
@@ -228,31 +228,73 @@ MltVideoProfile ProfilesDialog::getVideoProfile(QString name)
     return result;
 }
 
+
 // static
-QString ProfilesDialog::getProfileDescription(QString name)
+bool ProfilesDialog::existingProfileDescription(const QString &desc)
 {
-    QStringList profilesNames;
-    QStringList profilesFiles;
     QStringList profilesFilter;
     profilesFilter << "*";
 
     // List the Mlt profiles
-    profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
-    if (profilesFiles.contains(name)) {
-        KConfig confFile(KdenliveSettings::mltpath() + '/' + name, KConfig::SimpleConfig);
-        return confFile.entryMap().value("description");
+    QStringList profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
+    for (int i = 0; i < profilesFiles.size(); ++i) {
+        KConfig confFile(KdenliveSettings::mltpath() + profilesFiles.at(i), KConfig::SimpleConfig);
+        if (desc == confFile.entryMap().value("description")) return true;
     }
 
     // List custom profiles
     QStringList customProfiles = KGlobal::dirs()->findDirs("appdata", "profiles");
     for (int i = 0; i < customProfiles.size(); ++i) {
         profilesFiles = QDir(customProfiles.at(i)).entryList(profilesFilter, QDir::Files);
-        if (profilesFiles.contains(name)) {
-            KConfig confFile(customProfiles.at(i) + '/' + name, KConfig::SimpleConfig);
-            return confFile.entryMap().value("description");
+        for (int j = 0; j < profilesFiles.size(); ++j) {
+            KConfig confFile(customProfiles.at(i) + profilesFiles.at(j), KConfig::SimpleConfig);
+            if (desc == confFile.entryMap().value("description")) return true;
         }
     }
+    return false;
+}
 
+// static
+QString ProfilesDialog::existingProfile(MltVideoProfile profile)
+{
+    // Check if the profile has a matching entry in existing ones
+    QStringList profilesFilter;
+    profilesFilter << "*";
+
+    // Check the Mlt profiles
+    QStringList profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
+    for (int i = 0; i < profilesFiles.size(); ++i) {
+        KConfig confFile(KdenliveSettings::mltpath() + profilesFiles.at(i), KConfig::SimpleConfig);
+        if (profile.display_aspect_den != confFile.entryMap().value("display_aspect_den").toInt()) continue;
+        if (profile.display_aspect_num != confFile.entryMap().value("display_aspect_num").toInt()) continue;
+        if (profile.sample_aspect_den != confFile.entryMap().value("sample_aspect_den").toInt()) continue;
+        if (profile.sample_aspect_num != confFile.entryMap().value("sample_aspect_num").toInt()) continue;
+        if (profile.width != confFile.entryMap().value("width").toInt()) continue;
+        if (profile.height != confFile.entryMap().value("height").toInt()) continue;
+        if (profile.frame_rate_den != confFile.entryMap().value("frame_rate_den").toInt()) continue;
+        if (profile.frame_rate_num != confFile.entryMap().value("frame_rate_num").toInt()) continue;
+        if (profile.progressive != confFile.entryMap().value("progressive").toInt()) continue;
+        return profilesFiles.at(i);
+    }
+
+    // Check custom profiles
+    QStringList customProfiles = KGlobal::dirs()->findDirs("appdata", "profiles");
+    for (int i = 0; i < customProfiles.size(); ++i) {
+        profilesFiles = QDir(customProfiles.at(i)).entryList(profilesFilter, QDir::Files);
+        for (int j = 0; j < profilesFiles.size(); ++j) {
+            KConfig confFile(customProfiles.at(i) + profilesFiles.at(j), KConfig::SimpleConfig);
+            if (profile.display_aspect_den != confFile.entryMap().value("display_aspect_den").toInt()) continue;
+            if (profile.display_aspect_num != confFile.entryMap().value("display_aspect_num").toInt()) continue;
+            if (profile.sample_aspect_den != confFile.entryMap().value("sample_aspect_den").toInt()) continue;
+            if (profile.sample_aspect_num != confFile.entryMap().value("sample_aspect_num").toInt()) continue;
+            if (profile.width != confFile.entryMap().value("width").toInt()) continue;
+            if (profile.height != confFile.entryMap().value("height").toInt()) continue;
+            if (profile.frame_rate_den != confFile.entryMap().value("frame_rate_den").toInt()) continue;
+            if (profile.frame_rate_num != confFile.entryMap().value("frame_rate_num").toInt()) continue;
+            if (profile.progressive != confFile.entryMap().value("progressive").toInt()) continue;
+            return customProfiles.at(i) + profilesFiles.at(j);
+        }
+    }
     return QString();
 }
 
@@ -266,7 +308,7 @@ QMap <QString, QString> ProfilesDialog::getProfilesInfo()
     // List the Mlt profiles
     QStringList profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
     for (int i = 0; i < profilesFiles.size(); ++i) {
-        KConfig confFile(KdenliveSettings::mltpath() + '/' + profilesFiles.at(i), KConfig::SimpleConfig);
+        KConfig confFile(KdenliveSettings::mltpath() + profilesFiles.at(i), KConfig::SimpleConfig);
         QString desc = confFile.entryMap().value("description");
         if (!desc.isEmpty()) result.insert(desc, profilesFiles.at(i));
     }
@@ -276,9 +318,9 @@ QMap <QString, QString> ProfilesDialog::getProfilesInfo()
     for (int i = 0; i < customProfiles.size(); ++i) {
         profilesFiles = QDir(customProfiles.at(i)).entryList(profilesFilter, QDir::Files);
         for (int j = 0; j < profilesFiles.size(); ++j) {
-            KConfig confFile(customProfiles.at(i) + '/' + profilesFiles.at(j), KConfig::SimpleConfig);
+            KConfig confFile(customProfiles.at(i) + profilesFiles.at(j), KConfig::SimpleConfig);
             QString desc = confFile.entryMap().value("description");
-            if (!desc.isEmpty()) result.insert(desc, customProfiles.at(i) + '/' + profilesFiles.at(j));
+            if (!desc.isEmpty()) result.insert(desc, customProfiles.at(i) + profilesFiles.at(j));
         }
     }
     return result;
@@ -294,7 +336,7 @@ QMap< QString, QString > ProfilesDialog::getSettingsFromFile(const QString path)
 
     if (!path.contains('/')) {
         // This is an MLT profile
-        KConfig confFile(KdenliveSettings::mltpath() + '/' + path, KConfig::SimpleConfig);
+        KConfig confFile(KdenliveSettings::mltpath() + path, KConfig::SimpleConfig);
         return confFile.entryMap();
     } else {
         // This is a custom profile
@@ -314,7 +356,7 @@ QMap< QString, QString > ProfilesDialog::getSettingsForProfile(const QString pro
     // List the Mlt profiles
     profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
     for (int i = 0; i < profilesFiles.size(); ++i) {
-        KConfig confFile(KdenliveSettings::mltpath() + '/' + profilesFiles.at(i), KConfig::SimpleConfig);
+        KConfig confFile(KdenliveSettings::mltpath() + profilesFiles.at(i), KConfig::SimpleConfig);
         QMap< QString, QString > values = confFile.entryMap();
         if (values.value("description") == profileName) {
             values.insert("path", profilesFiles.at(i));
@@ -327,10 +369,10 @@ QMap< QString, QString > ProfilesDialog::getSettingsForProfile(const QString pro
     for (int i = 0; i < customProfiles.size(); ++i) {
         QStringList profiles = QDir(customProfiles.at(i)).entryList(profilesFilter, QDir::Files);
         for (int i = 0; i < profiles.size(); ++i) {
-            KConfig confFile(customProfiles.at(i) + '/' + profiles.at(i), KConfig::SimpleConfig);
+            KConfig confFile(customProfiles.at(i) + profiles.at(i), KConfig::SimpleConfig);
             QMap< QString, QString > values = confFile.entryMap();
             if (values.value("description") == profileName) {
-                values.insert("path", customProfiles.at(i) + '/' + profiles.at(i));
+                values.insert("path", customProfiles.at(i) + profiles.at(i));
                 return values;
             }
         }
@@ -349,7 +391,7 @@ QString ProfilesDialog::getPathFromDescription(const QString profileDesc)
     // List the Mlt profiles
     profilesFiles = QDir(KdenliveSettings::mltpath()).entryList(profilesFilter, QDir::Files);
     for (int i = 0; i < profilesFiles.size(); ++i) {
-        KConfig confFile(KdenliveSettings::mltpath() + '/' + profilesFiles.at(i), KConfig::SimpleConfig);
+        KConfig confFile(KdenliveSettings::mltpath() + profilesFiles.at(i), KConfig::SimpleConfig);
         QMap< QString, QString > values = confFile.entryMap();
         if (values.value("description") == profileDesc) return profilesFiles.at(i);
     }
@@ -359,14 +401,39 @@ QString ProfilesDialog::getPathFromDescription(const QString profileDesc)
     for (int i = 0; i < customProfiles.size(); ++i) {
         QStringList profiles = QDir(customProfiles.at(i)).entryList(profilesFilter, QDir::Files);
         for (int i = 0; i < profiles.size(); ++i) {
-            KConfig confFile(customProfiles.at(i) + '/' + profiles.at(i), KConfig::SimpleConfig);
+            KConfig confFile(customProfiles.at(i) + profiles.at(i), KConfig::SimpleConfig);
             QMap< QString, QString > values = confFile.entryMap();
-            if (values.value("description") == profileDesc) return customProfiles.at(i) + '/' + profiles.at(i);
+            if (values.value("description") == profileDesc) return customProfiles.at(i) + profiles.at(i);
         }
     }
     return QString();
 }
 
+// static
+void ProfilesDialog::saveProfile(MltVideoProfile &profile)
+{
+    int i = 0;
+    QString customName = "profiles/customprofile";
+    QString profilePath = KStandardDirs::locateLocal("appdata", customName + QString::number(i));
+    kDebug() << " TYING PROFILE FILE: " << profilePath;
+    while (KIO::NetAccess::exists(KUrl(profilePath), KIO::NetAccess::SourceSide, 0)) {
+        i++;
+        profilePath = KStandardDirs::locateLocal("appdata", customName + QString::number(i));
+    }
+    QFile file(profilePath);
+    if (!file.open(QIODevice::WriteOnly)) {
+        KMessageBox::sorry(0, i18n("Cannot write to file %1", profilePath));
+        return;
+    }
+    QTextStream out(&file);
+    out << "description=" << profile.description << "\n" << "frame_rate_num=" << profile.frame_rate_num << "\n" << "frame_rate_den=" << profile.frame_rate_den << "\n" << "width=" << profile.width << "\n" << "height=" << profile.height << "\n" << "progressive=" << profile.progressive << "\n" << "sample_aspect_num=" << profile.sample_aspect_num << "\n" << "sample_aspect_den=" << profile.sample_aspect_den << "\n" << "display_aspect_num=" << profile.display_aspect_num << "\n" << "display_aspect_den=" << profile.display_aspect_den << "\n";
+    if (file.error() != QFile::NoError) {
+        KMessageBox::error(0, i18n("Cannot write to file %1", profilePath));
+    }
+    file.close();
+    profile.path = profilePath;
+}
+
 
 void ProfilesDialog::slotUpdateDisplay()
 {
