@@ -33,12 +33,14 @@ public:
     ProfilesDialog(QWidget * parent = 0);
 
     void fillList(const QString selectedProfile = QString());
-    static QString getProfileDescription(QString name);
     static QMap< QString, QString > getSettingsForProfile(const QString profileName);
     static QMap< QString, QString > getSettingsFromFile(const QString path);
     static QString getPathFromDescription(const QString profileDesc);
     static MltVideoProfile getVideoProfile(QString name);
     static QMap <QString, QString> getProfilesInfo();
+    static void saveProfile(MltVideoProfile &profile);
+    static QString existingProfile(MltVideoProfile profile);
+    static bool existingProfileDescription(const QString &desc);
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
