@@ -33,7 +33,7 @@
 #include "projectlistview.h"
 #include "editclipcommand.h"
 #include "editfoldercommand.h"
-
+#include "ui_templateclip_ui.h"
 
 #include <KDebug>
 #include <KAction>
@@ -86,7 +86,11 @@ ProjectList::ProjectList(QWidget *parent) :
     layout->addWidget(m_toolbar);
     layout->addWidget(m_listView);
     setLayout(layout);
-    
+
+    m_queueTimer.setInterval(100);
+    connect(&m_queueTimer, SIGNAL(timeout()), this, SLOT(slotProcessNextClipInQueue()));
+    m_queueTimer.setSingleShot(true);
+
 
 
     connect(m_listView, SIGNAL(itemSelectionChanged()), this, SLOT(slotClipSelected()));
@@ -94,7 +98,7 @@ ProjectList::ProjectList(QWidget *parent) :
     connect(m_listView, SIGNAL(pauseMonitor()), this, SLOT(slotPauseMonitor()));
     connect(m_listView, SIGNAL(requestMenu(const QPoint &, QTreeWidgetItem *)), this, SLOT(slotContextMenu(const QPoint &, QTreeWidgetItem *)));
     connect(m_listView, SIGNAL(addClip()), this, SLOT(slotAddClip()));
-    connect(m_listView, SIGNAL(addClip(const QList <QUrl>, const QString &)), this, SLOT(slotAddClip(const QList <QUrl>, const QString &)));
+    connect(m_listView, SIGNAL(addClip(const QList <QUrl>, const QString &, const QString &)), this, SLOT(slotAddClip(const QList <QUrl>, const QString &, const QString &)));
     connect(m_listView, SIGNAL(itemChanged(QTreeWidgetItem *, int)), this, SLOT(slotItemEdited(QTreeWidgetItem *, int)));
     connect(m_listView, SIGNAL(showProperties(DocClipBase *)), this, SIGNAL(showClipProperties(DocClipBase *)));
 
@@ -149,7 +153,7 @@ void ProjectList::setupMenu(QMenu *addMenu, QAction *defaultAction)
     m_menu->addActions(addMenu->actions());
 }
 
-void ProjectList::setupGeneratorMenu(QMenu *addMenu)
+void ProjectList::setupGeneratorMenu(QMenu *addMenu, QMenu *transcodeMenu)
 {
     if (!addMenu) return;
     QMenu *menu = m_addButton->menu();
@@ -158,6 +162,8 @@ void ProjectList::setupGeneratorMenu(QMenu *addMenu)
 
     m_menu->addMenu(addMenu);
     if (addMenu->isEmpty()) addMenu->setEnabled(false);
+    m_menu->addMenu(transcodeMenu);
+    if (transcodeMenu->isEmpty()) transcodeMenu->setEnabled(false);
     m_menu->addAction(m_reloadAction);
     m_menu->addAction(m_editAction);
     m_menu->addAction(m_openAction);
@@ -166,7 +172,7 @@ void ProjectList::setupGeneratorMenu(QMenu *addMenu)
 }
 
 
-QByteArray ProjectList::headerInfo()
+QByteArray ProjectList::headerInfo() const
 {
     return m_listView->header()->saveState();
 }
@@ -203,12 +209,20 @@ void ProjectList::slotOpenClip()
 
 void ProjectList::slotReloadClip()
 {
-    ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
-    if (item && !item->isGroup()) {
-        if (item->clipType() == IMAGE) {
-            item->referencedClip()->producer()->set("force_reload", 1);
+    QList<QTreeWidgetItem *> selected = m_listView->selectedItems();
+    ProjectItem *item;
+    for (int i = 0; i < selected.count(); i++) {
+        item = static_cast <ProjectItem *>(selected.at(i));
+        if (item && !item->isGroup()) {
+            if (item->clipType() == IMAGE) {
+                item->referencedClip()->producer()->set("force_reload", 1);
+            } else if (item->clipType() == TEXT) {
+                if (!item->referencedClip()->getProperty("xmltemplate").isEmpty()) regenerateTemplate(item);
+            }
+            //requestClipInfo(item->toXml(), item->clipId(), true);
+            // Clear the file_hash value, which will cause a complete reload of the clip
+            emit getFileProperties(item->toXml(), item->clipId(), true);
         }
-        emit getFileProperties(item->toXml(), item->clipId(), false);
     }
 }
 
@@ -255,7 +269,10 @@ void ProjectList::slotUpdateClipProperties(const QString &id, QMap <QString, QSt
     ProjectItem *item = getItemById(id);
     if (item) {
         slotUpdateClipProperties(item, properties);
-        if (properties.contains("colour") || properties.contains("resource") || properties.contains("xmldata")) slotRefreshClipThumbnail(item);
+        if (properties.contains("colour") || properties.contains("resource") || properties.contains("xmldata") || properties.contains("force_aspect_ratio")) {
+            slotRefreshClipThumbnail(item);
+            emit refreshClip();
+        }
         if (properties.contains("out")) item->changeDuration(properties.value("out").toInt());
     }
 }
@@ -264,6 +281,7 @@ void ProjectList::slotUpdateClipProperties(ProjectItem *clip, QMap <QString, QSt
 {
     if (!clip) return;
     if (!clip->isGroup()) clip->setProperties(properties);
+    if (properties.contains("xmldata")) regenerateTemplateImage(clip);
     if (properties.contains("name")) {
         m_listView->blockSignals(true);
         clip->setText(1, properties.value("name"));
@@ -293,7 +311,14 @@ void ProjectList::slotItemEdited(QTreeWidgetItem *item, int column)
             QMap <QString, QString> newprops;
             oldprops["description"] = clip->referencedClip()->getProperty("description");
             newprops["description"] = item->text(2);
-            slotUpdateClipProperties(clip, newprops);
+
+            if (clip->clipType() == TEXT && !clip->referencedClip()->getProperty("xmltemplate").isEmpty()) {
+                // This is a text template clip, update the image
+                oldprops.insert("xmldata", clip->referencedClip()->getProperty("xmldata"));
+                newprops.insert("xmldata", generateTemplateXml(clip->referencedClip()->getProperty("xmltemplate"), item->text(2)).toString());
+            }
+
+            slotUpdateClipProperties(clip->clipId(), newprops);
             EditClipCommand *command = new EditClipCommand(this, clip->clipId(), oldprops, newprops, false);
             m_commandStack->push(command);
         }
@@ -356,10 +381,10 @@ void ProjectList::slotRemoveClip()
         if (item->isGroup()) folderids[item->groupName()] = item->clipId();
         else ids << item->clipId();
         if (item->numReferences() > 0) {
-            if (KMessageBox::questionYesNo(this, i18np("Delete clip <b>%2</b> ?<br>This will also remove the clip in timeline", "Delete clip <b>%2</b> ?<br>This will also remove its %1 clips in timeline", item->numReferences(), item->names().at(1)), i18n("Delete Clip")) != KMessageBox::Yes) return;
+            if (KMessageBox::questionYesNo(this, i18np("Delete clip <b>%2</b>?<br>This will also remove the clip in timeline", "Delete clip <b>%2</b>?<br>This will also remove its %1 clips in timeline", item->numReferences(), item->names().at(1)), i18n("Delete Clip")) != KMessageBox::Yes) return;
         } else if (item->isGroup() && item->childCount() > 0) {
             int children = item->childCount();
-            if (KMessageBox::questionYesNo(this, i18n("Delete folder <b>%2</b> ?<br>This will also remove the %1 clips in that folder", children, item->names().at(1)), i18n("Delete Folder")) != KMessageBox::Yes) return;
+            if (KMessageBox::questionYesNo(this, i18n("Delete folder <b>%2</b>?<br>This will also remove the %1 clips in that folder", children, item->names().at(1)), i18n("Delete Folder")) != KMessageBox::Yes) return;
             for (int i = 0; i < children; ++i) {
                 ProjectItem *child = static_cast <ProjectItem *>(item->child(i));
                 ids << child->clipId();
@@ -434,7 +459,7 @@ void ProjectList::slotAddFolder(const QString foldername, const QString &clipId,
             QStringList text;
             text << QString() << foldername;
             m_listView->blockSignals(true);
-            (void) new ProjectItem(m_listView, text, clipId);
+            m_listView->setCurrentItem(new ProjectItem(m_listView, text, clipId));
             m_doc->clipManager()->addFolder(clipId, foldername);
             m_listView->blockSignals(false);
         }
@@ -478,8 +503,15 @@ void ProjectList::slotAddClip(DocClipBase *clip, bool getProperties)
         if (parentitem) item = new ProjectItem(parentitem, clip);
     }
     if (item == NULL) item = new ProjectItem(m_listView, clip);
-
     KUrl url = clip->fileURL();
+
+    if (getProperties == false && !clip->getClipHash().isEmpty()) {
+        QString cachedPixmap = m_doc->projectFolder().path(KUrl::AddTrailingSlash) + "thumbs/" + clip->getClipHash() + ".png";
+        if (QFile::exists(cachedPixmap)) {
+            item->setIcon(0, QPixmap(cachedPixmap));
+        }
+    }
+
     if (!url.isEmpty() && KdenliveSettings::activate_nepomuk()) {
         // if file has Nepomuk comment, use it
         Nepomuk::Resource f(url.path());
@@ -501,26 +533,27 @@ void ProjectList::slotResetProjectList()
 
 void ProjectList::requestClipInfo(const QDomElement xml, const QString id)
 {
-    kDebug() << " PRG LIST REQUEST CLP INFO: " << id;
     m_infoQueue.insert(id, xml);
     m_listView->setEnabled(false);
-    if (m_infoQueue.count() == 1) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
+    if (!m_queueTimer.isActive()) m_queueTimer.start();
+    //if (m_infoQueue.count() == 1 || ) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
 }
 
 void ProjectList::slotProcessNextClipInQueue()
 {
     if (m_infoQueue.isEmpty()) {
-        m_listView->setEnabled(true);
+        slotProcessNextThumbnail();
         return;
     }
-    QMap<QString, QDomElement>::const_iterator i = m_infoQueue.constBegin();
-    if (i != m_infoQueue.constEnd()) {
-        const QDomElement dom = i.value();
-        const QString id = i.key();
-        m_infoQueue.remove(i.key());
-        emit getFileProperties(dom, id, true);
+
+    QMap<QString, QDomElement>::const_iterator j = m_infoQueue.constBegin();
+    if (j != m_infoQueue.constEnd()) {
+        const QDomElement dom = j.value();
+        const QString id = j.key();
+        m_infoQueue.remove(j.key());
+        emit getFileProperties(dom, id, false);
     }
-    if (m_infoQueue.isEmpty()) m_listView->setEnabled(true);
+    if (!m_infoQueue.isEmpty()) m_queueTimer.start();
 }
 
 void ProjectList::slotUpdateClip(const QString &id)
@@ -537,29 +570,25 @@ void ProjectList::updateAllClips()
     while (*it) {
         ProjectItem *item = static_cast <ProjectItem *>(*it);
         if (!item->isGroup()) {
+            DocClipBase *clip = item->referencedClip();
+            if (clip->clipType() == TEXT && !QFile::exists(clip->fileURL().path())) {
+                // regenerate text clip image if required
+                TitleWidget *dia_ui = new TitleWidget(KUrl(), QString(), m_render, this);
+                QDomDocument doc;
+                doc.setContent(clip->getProperty("xmldata"));
+                dia_ui->setXml(doc);
+                QImage pix = dia_ui->renderedPixmap();
+                pix.save(clip->fileURL().path());
+                delete dia_ui;
+            }
+
             if (item->referencedClip()->producer() == NULL) {
-                DocClipBase *clip = item->referencedClip();
-                if (clip->clipType() == TEXT && !QFile::exists(clip->fileURL().path())) {
-                    // regenerate text clip image if required
-                    TitleWidget *dia_ui = new TitleWidget(KUrl(), QString(), m_render, this);
-                    QDomDocument doc;
-                    doc.setContent(clip->getProperty("xmldata"));
-                    dia_ui->setXml(doc);
-                    QImage pix = dia_ui->renderedPixmap();
-                    pix.save(clip->fileURL().path());
-                    delete dia_ui;
-                }
                 if (clip->isPlaceHolder() == false) requestClipInfo(clip->toXML(), clip->getId());
                 else item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
             } else {
-                QString cachedPixmap = m_doc->projectFolder().path() + "/thumbs/" + item->getClipHash() + ".png";
-                if (QFile::exists(cachedPixmap)) {
-                    //kDebug()<<"// USING CACHED PIX: "<<cachedPixmap;
-                    m_listView->blockSignals(true);
-                    item->setIcon(0, QPixmap(cachedPixmap));
-                    m_listView->blockSignals(false);
-                } else requestClipThumbnail(item->clipId());
-
+                if (item->icon(0).isNull()) {
+                    requestClipThumbnail(clip->getId());
+                }
                 if (item->data(1, DurationRole).toString().isEmpty()) {
                     m_listView->blockSignals(true);
                     item->changeDuration(item->referencedClip()->producer()->get_playtime());
@@ -573,16 +602,16 @@ void ProjectList::updateAllClips()
         }
         ++it;
     }
-    QTimer::singleShot(500, this, SLOT(slotCheckForEmptyQueue()));
+    if (m_infoQueue.isEmpty()) slotProcessNextThumbnail();
 }
 
-void ProjectList::slotAddClip(const QList <QUrl> givenList, QString group)
+void ProjectList::slotAddClip(const QList <QUrl> givenList, const QString &groupName, const QString &groupId)
 {
     if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
     KUrl::List list;
     if (givenList.isEmpty()) {
         // Build list of mime types
-        QStringList mimeTypes = QStringList() << "application/x-kdenlive" << "video/x-flv" << "application/vnd.rn-realmedia" << "video/x-dv" << "video/dv" << "video/x-msvideo" << "video/mpeg" << "video/x-ms-wmv" << "audio/mpeg" << "audio/x-mp3" << "audio/x-wav" << "application/ogg" << "video/mp4" << "video/quicktime" << "image/gif" << "image/jpeg" << "image/png" << "image/x-tga" << "image/x-bmp" << "image/svg+xml" << "image/tiff" << "image/x-xcf-gimp" << "image/x-vnd.adobe.photoshop" << "image/x-pcx" << "image/x-exr" << "video/mlt-playlist" << "audio/x-flac" << "audio/mp4" << "video/x-matroska" << "audio/x-matroska";
+        QStringList mimeTypes = QStringList() << "application/x-kdenlive" << "video/x-flv" << "application/vnd.rn-realmedia" << "video/x-dv" << "video/dv" << "video/x-msvideo" << "video/x-matroska" << "video/mlt-playlist" << "video/mpeg" << "video/ogg" << "video/x-ms-wmv" << "audio/x-flac" << "audio/x-matroska" << "audio/mp4" << "audio/mpeg" << "audio/x-mp3" << "audio/ogg" << "audio/x-wav" << "application/ogg" << "video/mp4" << "video/quicktime" << "image/gif" << "image/jpeg" << "image/png" << "image/x-tga" << "image/x-bmp" << "image/svg+xml" << "image/tiff" << "image/x-xcf-gimp" << "image/x-vnd.adobe.photoshop" << "image/x-pcx" << "image/x-exr";
 
         QString allExtensions;
         foreach(const QString& mimeType, mimeTypes) {
@@ -602,67 +631,44 @@ void ProjectList::slotAddClip(const QList <QUrl> givenList, QString group)
     }
     if (list.isEmpty()) return;
 
-    QString groupId;
-    if (group.isEmpty()) {
-        ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
-        if (item && !item->isGroup()) {
-            while (item->parent()) {
-                item = static_cast <ProjectItem*>(item->parent());
-                if (item->isGroup()) break;
-            }
-        }
-        if (item && item->isGroup()) {
-            group = item->groupName();
-            groupId = item->clipId();
-        }
-    }
-    m_doc->slotAddClipList(list, group, groupId);
+    if (givenList.isEmpty()) {
+        QStringList groupInfo = getGroup();
+        m_doc->slotAddClipList(list, groupInfo.at(0), groupInfo.at(1));
+    } else m_doc->slotAddClipList(list, groupName, groupId);
 }
 
-void ProjectList::slotRemoveInvalidClip(const QString &id)
+void ProjectList::slotRemoveInvalidClip(const QString &id, bool replace)
 {
     ProjectItem *item = getItemById(id);
+    QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
     if (item) {
         const QString path = item->referencedClip()->fileURL().path();
-        if (!path.isEmpty()) KMessageBox::sorry(this, i18n("Clip <b>%1</b><br>is invalid, will be removed from project.", path));
+        if (!path.isEmpty()) {
+            if (replace) KMessageBox::sorry(this, i18n("Clip <b>%1</b><br>is invalid, will be removed from project.", path));
+            else {
+                if (KMessageBox::questionYesNo(this, i18n("Clip <b>%1</b><br>is missing or invalid. Remove it from project?", path), i18n("Invalid clip")) == KMessageBox::Yes) replace = true;
+            }
+        }
         QList <QString> ids;
         ids << id;
-        m_doc->deleteProjectClip(ids);
+        if (replace) m_doc->deleteProjectClip(ids);
     }
-    if (!m_infoQueue.isEmpty()) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
-    else m_listView->setEnabled(true);
 }
 
 void ProjectList::slotAddColorClip()
 {
     if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
     QDialog *dia = new QDialog(this);
-    Ui::ColorClip_UI *dia_ui = new Ui::ColorClip_UI();
-    dia_ui->setupUi(dia);
-    dia_ui->clip_name->setText(i18n("Color Clip"));
-    dia_ui->clip_duration->setText(KdenliveSettings::color_duration());
+    Ui::ColorClip_UI dia_ui;
+    dia_ui.setupUi(dia);
+    dia_ui.clip_name->setText(i18n("Color Clip"));
+    dia_ui.clip_duration->setText(KdenliveSettings::color_duration());
     if (dia->exec() == QDialog::Accepted) {
-        QString color = dia_ui->clip_color->color().name();
+        QString color = dia_ui.clip_color->color().name();
         color = color.replace(0, 1, "0x") + "ff";
-
-        QString group;
-        QString groupId;
-        ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
-        if (item && !item->isGroup()) {
-            while (item->parent()) {
-                item = static_cast <ProjectItem*>(item->parent());
-                if (item->isGroup()) break;
-            }
-        }
-        if (item && item->isGroup()) {
-            group = item->groupName();
-            groupId = item->clipId();
-        }
-
-        m_doc->clipManager()->slotAddColorClipFile(dia_ui->clip_name->text(), color, dia_ui->clip_duration->text(), group, groupId);
-        m_doc->setModified(true);
+        QStringList groupInfo = getGroup();
+        m_doc->slotCreateColorClip(dia_ui.clip_name->text(), color, dia_ui.clip_duration->text(), groupInfo.at(0), groupInfo.at(1));
     }
-    delete dia_ui;
     delete dia;
 }
 
@@ -670,34 +676,60 @@ void ProjectList::slotAddColorClip()
 void ProjectList::slotAddSlideshowClip()
 {
     if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
-    SlideshowClip *dia = new SlideshowClip(this);
+    SlideshowClip *dia = new SlideshowClip(m_timecode, this);
 
     if (dia->exec() == QDialog::Accepted) {
-
-        QString group;
-        QString groupId;
-        ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
-        if (item && !item->isGroup()) {
-            while (item->parent()) {
-                item = static_cast <ProjectItem*>(item->parent());
-                if (item->isGroup()) break;
-            }
-        }
-        if (item && item->isGroup()) {
-            group = item->groupName();
-            groupId = item->clipId();
-        }
-
-        m_doc->clipManager()->slotAddSlideshowClipFile(dia->clipName(), dia->selectedPath(), dia->imageCount(), dia->clipDuration(), dia->loop(), dia->fade(), dia->lumaDuration(), dia->lumaFile(), dia->softness(), group, groupId);
-        m_doc->setModified(true);
+        QStringList groupInfo = getGroup();
+        m_doc->slotCreateSlideshowClipFile(dia->clipName(), dia->selectedPath(), dia->imageCount(), dia->clipDuration(), dia->loop(), dia->fade(), dia->lumaDuration(), dia->lumaFile(), dia->softness(), groupInfo.at(0), groupInfo.at(1));
     }
     delete dia;
 }
 
 void ProjectList::slotAddTitleClip()
 {
-    QString group;
-    QString groupId;
+    QStringList groupInfo = getGroup();
+    m_doc->slotCreateTextClip(groupInfo.at(0), groupInfo.at(1));
+}
+
+void ProjectList::slotAddTitleTemplateClip()
+{
+    QStringList groupInfo = getGroup();
+    if (!m_commandStack) kDebug() << "!!!!!!!!!!!!!!!! NO CMD STK";
+
+    // Get the list of existing templates
+    QStringList filter;
+    filter << "*.kdenlivetitle";
+    const QString path = m_doc->projectFolder().path(KUrl::AddTrailingSlash) + "titles/";
+    QStringList templateFiles = QDir(path).entryList(filter, QDir::Files);
+
+    QDialog *dia = new QDialog(this);
+    Ui::TemplateClip_UI dia_ui;
+    dia_ui.setupUi(dia);
+    for (int i = 0; i < templateFiles.size(); ++i) {
+        dia_ui.template_list->comboBox()->addItem(templateFiles.at(i), path + templateFiles.at(i));
+    }
+    dia_ui.template_list->fileDialog()->setFilter("*.kdenlivetitle");
+    //warning: setting base directory doesn't work??
+    KUrl startDir(path);
+    dia_ui.template_list->fileDialog()->setUrl(startDir);
+    dia_ui.description->setHidden(true);
+    if (dia->exec() == QDialog::Accepted) {
+        QString textTemplate = dia_ui.template_list->comboBox()->itemData(dia_ui.template_list->comboBox()->currentIndex()).toString();
+        if (textTemplate.isEmpty()) textTemplate = dia_ui.template_list->comboBox()->currentText();
+        if (dia_ui.normal_clip->isChecked()) {
+            // Create a normal title clip
+            m_doc->slotCreateTextClip(groupInfo.at(0), groupInfo.at(1), textTemplate);
+        } else {
+            // Create a cloned template clip
+            m_doc->slotCreateTextTemplateClip(groupInfo.at(0), groupInfo.at(1), KUrl(textTemplate));
+        }
+    }
+    delete dia;
+}
+
+QStringList ProjectList::getGroup() const
+{
+    QStringList result;
     ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
     if (item && !item->isGroup()) {
         while (item->parent()) {
@@ -706,11 +738,10 @@ void ProjectList::slotAddTitleClip()
         }
     }
     if (item && item->isGroup()) {
-        group = item->groupName();
-        groupId = item->clipId();
-    }
-
-    m_doc->slotCreateTextClip(group, groupId);
+        result << item->groupName();
+        result << item->clipId();
+    } else result << QString() << QString();
+    return result;
 }
 
 void ProjectList::setDocument(KdenliveDoc *doc)
@@ -721,6 +752,11 @@ void ProjectList::setDocument(KdenliveDoc *doc)
     m_thumbnailQueue.clear();
     m_infoQueue.clear();
     m_refreshed = false;
+    m_fps = doc->fps();
+    m_timecode = doc->timecode();
+    m_commandStack = doc->commandStack();
+    m_doc = doc;
+
     QMap <QString, QString> flist = doc->clipManager()->documentFolderList();
     QMapIterator<QString, QString> f(flist);
     while (f.hasNext()) {
@@ -733,12 +769,6 @@ void ProjectList::setDocument(KdenliveDoc *doc)
         slotAddClip(list.at(i), false);
     }
 
-    m_fps = doc->fps();
-    m_timecode = doc->timecode();
-    m_commandStack = doc->commandStack();
-    m_doc = doc;
-    QTreeWidgetItem *first = m_listView->topLevelItem(0);
-    if (first) m_listView->setCurrentItem(first);
     m_listView->blockSignals(false);
     m_toolbar->setEnabled(true);
 }
@@ -763,18 +793,35 @@ void ProjectList::slotCheckForEmptyQueue()
     if (!m_refreshed && m_thumbnailQueue.isEmpty() && m_infoQueue.isEmpty()) {
         m_refreshed = true;
         emit loadingIsOver();
-    } else QTimer::singleShot(500, this, SLOT(slotCheckForEmptyQueue()));
+    } else QTimer::singleShot(300, this, SLOT(slotCheckForEmptyQueue()));
 }
 
-void ProjectList::requestClipThumbnail(const QString &id)
+void ProjectList::reloadClipThumbnails()
+{
+    m_thumbnailQueue.clear();
+    QTreeWidgetItemIterator it(m_listView);
+    while (*it) {
+        if (!((ProjectItem *)(*it))->isGroup())
+            m_thumbnailQueue << ((ProjectItem *)(*it))->clipId();
+        ++it;
+    }
+    QTimer::singleShot(300, this, SLOT(slotProcessNextThumbnail()));
+}
+
+void ProjectList::requestClipThumbnail(const QString id)
 {
     m_thumbnailQueue.append(id);
-    if (m_thumbnailQueue.count() == 1) QTimer::singleShot(300, this, SLOT(slotProcessNextThumbnail()));
 }
 
 void ProjectList::slotProcessNextThumbnail()
 {
-    if (m_thumbnailQueue.isEmpty()) {
+    if (m_thumbnailQueue.isEmpty() && m_infoQueue.isEmpty()) {
+        m_listView->setEnabled(true);
+        slotCheckForEmptyQueue();
+        return;
+    }
+    if (!m_infoQueue.isEmpty()) {
+        //QTimer::singleShot(300, this, SLOT(slotProcessNextThumbnail()));
         return;
     }
     slotRefreshClipThumbnail(m_thumbnailQueue.takeFirst(), false);
@@ -790,20 +837,22 @@ void ProjectList::slotRefreshClipThumbnail(const QString &clipId, bool update)
 void ProjectList::slotRefreshClipThumbnail(ProjectItem *item, bool update)
 {
     if (item) {
-        if (!item->referencedClip()) return;
         int height = 50;
         int width = (int)(height  * m_render->dar());
         DocClipBase *clip = item->referencedClip();
         if (!clip) slotProcessNextThumbnail();
         QPixmap pix;
         if (clip->clipType() == AUDIO) pix = KIcon("audio-x-generic").pixmap(QSize(width, height));
+        else if (clip->clipType() == TEXT || clip->clipType() == IMAGE) pix = KThumb::getFrame(item->referencedClip()->producer(), 0, width, height);
         else pix = item->referencedClip()->thumbProducer()->extractImage(item->referencedClip()->getClipThumbFrame(), width, height);
-        m_listView->blockSignals(true);
-        item->setIcon(0, pix);
-        m_listView->blockSignals(false);
-        m_doc->cachePixmap(item->getClipHash(), pix);
+        if (!pix.isNull()) {
+            m_listView->blockSignals(true);
+            item->setIcon(0, pix);
+            m_listView->blockSignals(false);
+            m_doc->cachePixmap(item->getClipHash(), pix);
+        }
         if (update) emit projectModified();
-        if (!m_thumbnailQueue.isEmpty()) QTimer::singleShot(300, this, SLOT(slotProcessNextThumbnail()));
+        QTimer::singleShot(100, this, SLOT(slotProcessNextThumbnail()));
     }
 }
 
@@ -814,22 +863,31 @@ void ProjectList::slotReplyGetFileProperties(const QString &clipId, Mlt::Produce
         m_listView->blockSignals(true);
         item->setProperties(properties, metadata);
         Q_ASSERT_X(item->referencedClip(), "void ProjectList::slotReplyGetFileProperties", QString("Item with groupName %1 does not have a clip associated").arg(item->groupName()).toLatin1());
-        if (replace) item->referencedClip()->setProducer(producer);
-        else {
+        item->referencedClip()->setProducer(producer, replace);
+        emit receivedClipDuration(clipId);
+        if (replace) {
+            // update clip in clip monitor
+            emit clipSelected(NULL);
+            emit clipSelected(item->referencedClip());
+        }
+        /*else {
             // Check if duration changed.
             emit receivedClipDuration(clipId);
             delete producer;
-        }
+        }*/
         m_listView->blockSignals(false);
+        if (item->icon(0).isNull()) {
+            requestClipThumbnail(clipId);
+        }
     } else kDebug() << "////////  COULD NOT FIND CLIP TO UPDATE PRPS...";
-    if (!m_infoQueue.isEmpty()) QTimer::singleShot(300, this, SLOT(slotProcessNextClipInQueue()));
-    else m_listView->setEnabled(true);
+
+    slotProcessNextClipInQueue();
 }
 
 void ProjectList::slotReplyGetImage(const QString &clipId, const QPixmap &pix)
 {
     ProjectItem *item = getItemById(clipId);
-    if (item) {
+    if (item && !pix.isNull()) {
         m_listView->blockSignals(true);
         item->setIcon(0, pix);
         m_doc->cachePixmap(item->getClipHash(), pix);
@@ -882,4 +940,66 @@ void ProjectList::slotSelectClip(const QString &ix)
     }
 }
 
+QString ProjectList::currentClipUrl() const
+{
+    ProjectItem *item = static_cast <ProjectItem*>(m_listView->currentItem());
+    if (item == NULL) return QString();
+    return item->clipUrl().path();
+}
+
+void ProjectList::regenerateTemplate(const QString &id)
+{
+    ProjectItem *clip = getItemById(id);
+    if (clip) regenerateTemplate(clip);
+}
+
+void ProjectList::regenerateTemplate(ProjectItem *clip)
+{
+    // Generate image for template clip
+    const QString comment = clip->referencedClip()->getProperty("description");
+    const QString path = clip->referencedClip()->getProperty("xmltemplate");
+    QDomDocument doc = generateTemplateXml(path, comment);
+    TitleWidget *dia_ui = new TitleWidget(KUrl(), QString(), m_render, this);
+    dia_ui->setXml(doc);
+    QImage pix = dia_ui->renderedPixmap();
+    pix.save(clip->clipUrl().path());
+    delete dia_ui;
+    clip->referencedClip()->producer()->set("force_reload", 1);
+}
+
+void ProjectList::regenerateTemplateImage(ProjectItem *clip)
+{
+    // Generate image for template clip
+    TitleWidget *dia_ui = new TitleWidget(KUrl(), QString(), m_render, this);
+    QDomDocument doc;
+    doc.setContent(clip->referencedClip()->getProperty("xmldata"));
+    dia_ui->setXml(doc);
+    QImage pix = dia_ui->renderedPixmap();
+    pix.save(clip->clipUrl().path());
+    delete dia_ui;
+}
+
+QDomDocument ProjectList::generateTemplateXml(QString path, const QString &replaceString)
+{
+    QDomDocument doc;
+    QFile file(path);
+    if (!file.open(QIODevice::ReadOnly)) {
+        kWarning() << "ERROR, CANNOT READ: " << path;
+        return doc;
+    }
+    if (!doc.setContent(&file)) {
+        kWarning() << "ERROR, CANNOT READ: " << path;
+        file.close();
+        return doc;
+    }
+    file.close();
+    QDomNodeList texts = doc.elementsByTagName("content");
+    for (int i = 0; i < texts.count(); i++) {
+        QString data = texts.item(i).firstChild().nodeValue();
+        data.replace("%s", replaceString);
+        texts.item(i).firstChild().setNodeValue(data);
+    }
+    return doc;
+}
+
 #include "projectlist.moc"
