@@ -28,7 +28,7 @@
 #include <QPainter>
 #include <QItemDelegate>
 #include <QUndoStack>
-
+#include <QTimer>
 
 #include <KTreeWidgetSearchLine>
 #include <KUrl>
@@ -124,10 +124,13 @@ public:
     void setRenderer(Render *projectRender);
     void slotUpdateClipProperties(const QString &id, QMap <QString, QString> properties);
     void updateAllClips();
-    QByteArray headerInfo();
+    QByteArray headerInfo() const;
     void setHeaderInfo(const QByteArray &state);
     void setupMenu(QMenu *addMenu, QAction *defaultAction);
-    void setupGeneratorMenu(QMenu *addMenu);
+    void setupGeneratorMenu(QMenu *addMenu, QMenu *transcodeMenu);
+    QString currentClipUrl() const;
+    void reloadClipThumbnails();
+    QDomDocument generateTemplateXml(QString data, const QString &replaceString);
 
 public slots:
     void setDocument(KdenliveDoc *doc);
@@ -138,15 +141,17 @@ public slots:
     void slotUpdateClip(const QString &id);
     void slotRefreshClipThumbnail(const QString &clipId, bool update = true);
     void slotRefreshClipThumbnail(ProjectItem *item, bool update = true);
-    void slotRemoveInvalidClip(const QString &id);
+    void slotRemoveInvalidClip(const QString &id, bool replace);
     void slotSelectClip(const QString &ix);
     void slotRemoveClip();
-    void slotAddClip(const QList <QUrl> givenList = QList <QUrl> (), QString group = QString());
+    void slotAddClip(const QList <QUrl> givenList = QList <QUrl> (), const QString &groupName = QString(), const QString &groupId = QString());
     void slotAddFolder(const QString foldername, const QString &clipId, bool remove, bool edit = false);
     void slotResetProjectList();
     void slotOpenClip();
     void slotEditClip();
     void slotReloadClip();
+    void slotAddColorClip();
+    void regenerateTemplate(const QString &id);
 
 private:
     ProjectListView *m_listView;
@@ -154,6 +159,7 @@ private:
     Timecode m_timecode;
     double m_fps;
     QToolBar *m_toolbar;
+    QTimer m_queueTimer;
     QMenu *m_menu;
     QUndoStack *m_commandStack;
     void selectItemById(const QString &clipId);
@@ -168,17 +174,21 @@ private:
     bool m_refreshed;
     QToolButton *m_addButton;
     QMap <QString, QDomElement> m_infoQueue;
+    QMap <QString, QDomElement> m_producerQueue;
     void requestClipInfo(const QDomElement xml, const QString id);
     QList <QString> m_thumbnailQueue;
-    void requestClipThumbnail(const QString &id);
+    void requestClipThumbnail(const QString id);
     void deleteProjectFolder(QMap <QString, QString> map);
     void editFolder(const QString folderName, const QString oldfolderName, const QString &clipId);
+    QStringList getGroup() const;
+    void regenerateTemplate(ProjectItem *clip);
+    void regenerateTemplateImage(ProjectItem *clip);
 
 private slots:
     void slotClipSelected();
-    void slotAddColorClip();
     void slotAddSlideshowClip();
     void slotAddTitleClip();
+    void slotAddTitleTemplateClip();
     void slotContextMenu(const QPoint &pos, QTreeWidgetItem *);
     void slotAddFolder();
     /** This is triggered when a clip description has been modified */
@@ -198,6 +208,7 @@ signals:
     void projectModified();
     void loadingIsOver();
     void clipNameChanged(const QString, const QString);
+    void refreshClip();
 };
 
 #endif
