@@ -41,6 +41,7 @@ protected:
     virtual void contextMenuEvent(QContextMenuEvent * event);
     virtual void mouseDoubleClickEvent(QMouseEvent * event);
     virtual void mousePressEvent(QMouseEvent *event);
+    virtual void mouseReleaseEvent(QMouseEvent *event);
     virtual void mouseMoveEvent(QMouseEvent *event);
     virtual void dragEnterEvent(QDragEnterEvent *event);
     virtual void dropEvent(QDropEvent *event);
@@ -61,7 +62,7 @@ private slots:
 signals:
     void requestMenu(const QPoint &, QTreeWidgetItem *);
     void addClip();
-    void addClip(const QList <QUrl>, const QString &);
+    void addClip(const QList <QUrl>, const QString &, const QString &);
     void showProperties(DocClipBase *);
     void focusMonitor();
     void pauseMonitor();
