@@ -18,15 +18,17 @@
 #ifndef RENDERER_H
 #define RENDERER_H
 
+#include "gentime.h"
+#include "definitions.h"
+
+#include <kurl.h>
+
 #include <qdom.h>
 #include <qstring.h>
 #include <qmap.h>
 #include <QList>
+#include <QEvent>
 
-#include <kurl.h>
-
-#include "gentime.h"
-#include "definitions.h"
 
 /**Render encapsulates the client side of the interface to a renderer.
 From Kdenlive's point of view, you treat the Render object as the
@@ -50,10 +52,22 @@ class Frame;
 class Producer;
 class Filter;
 class Profile;
-class Multitrack;
+class Service;
 };
 
 
+class MltErrorEvent : public QEvent
+{
+public:
+    MltErrorEvent(QString message) : QEvent(QEvent::User), m_message(message) {}
+    QString message() const {
+        return m_message;
+    }
+
+private:
+    QString m_message;
+};
+
 
 class Render: public QObject
 {
@@ -69,7 +83,7 @@ Q_OBJECT public:
     /** Seeks the renderer clip to the given time. */
     void seek(GenTime time);
     void seekToFrame(int pos);
-    bool m_isBlocked;
+    int m_isBlocked;
 
     //static QPixmap getVideoThumbnail(char *profile, QString file, int frame, int width, int height);
     QPixmap getImageThumbnail(KUrl url, int width, int height);
@@ -91,9 +105,9 @@ Q_OBJECT public:
 
     /** Wraps the VEML command of the same name. Sets the current scene list to
     be list. */
-    void setSceneList(QDomDocument list, int position = 0);
-    void setSceneList(QString playlist, int position = 0);
-    void setProducer(Mlt::Producer *producer, int position);
+    int setSceneList(QDomDocument list, int position = 0);
+    int setSceneList(QString playlist, int position = 0);
+    int setProducer(Mlt::Producer *producer, int position);
     const QString sceneList();
     bool saveSceneList(QString path, QDomElement kdenliveData = QDomElement());
 
@@ -189,6 +203,7 @@ Q_OBJECT public:
 
     QList <Mlt::Producer *> producersList();
     void updatePreviewSettings();
+    void setDropFrames(bool show);
 
 private:   // Private attributes & methods
     /** The name of this renderer - useful to identify the renderes by what they do - e.g. background rendering, workspace monitor, etc... */
@@ -220,6 +235,7 @@ private:   // Private attributes & methods
     /** Sets the description of this renderer to desc. */
     void closeMlt();
     void mltCheckLength();
+    void mltPasteEffects(Mlt::Producer *source, Mlt::Producer *dest);
     QMap<QString, QString> mltGetTransitionParamsFromXml(QDomElement xml);
     QMap<QString, Mlt::Producer *> m_slowmotionProducers;
     void buildConsumer();
@@ -230,7 +246,7 @@ private slots:  // Private slots
     /** refresh monitor display */
     void refresh();
     void slotOsdTimeout();
-    void connectPlaylist();
+    int connectPlaylist();
     //void initSceneList();
 
 signals:   // Signals
@@ -255,8 +271,9 @@ signals:   // Signals
     void durationChanged(int);
     void rendererPosition(int);
     void rendererStopped(int);
-    void removeInvalidClip(const QString &);
+    void removeInvalidClip(const QString &, bool replaceProducer);
     void refreshDocumentProducers();
+    void blockMonitors();
 
 public slots:  // Public slots
     /** Start Consumer */
