@@ -51,8 +51,9 @@ public:
     QString getTimecode(const GenTime & time, double fps) const;
     int getFrameCount(const QString duration, double fps) const;
     static QString getEasyTimecode(const GenTime & time, const double &fps);
-    QString getTimecodeFromFrames(int frames);
-    int fps();
+    static QString getStringTimecode(int frames, const double &fps);
+    QString getTimecodeFromFrames(int frames) const;
+    int fps() const;
 
 private:
     Formats m_format;
