@@ -26,7 +26,7 @@ class QGraphicsPolygonItem;
 
 class TitleDocument
 {
-    QGraphicsScene* m_scene;
+
 public:
     TitleDocument();
     void setScene(QGraphicsScene* scene);
@@ -38,7 +38,11 @@ public:
      * \returns The background color of the document, inclusive alpha. If none found, returns (0,0,0,0) */
     QColor getBackgroundColor();
 
+    enum ItemOrigin {OriginXLeft = 0, OriginYTop = 1};
+    enum AxisPosition {AxisDefault = 0, AxisInverted = 1};
+
 private:
+    QGraphicsScene* m_scene;
     QString colorToString(const QColor&);
     QString rectFToString(const QRectF&);
     QRectF stringToRect(const QString &);
