@@ -36,11 +36,12 @@
 
 #include <QScrollBar>
 
-TrackView::TrackView(KdenliveDoc *doc, QWidget *parent) :
+TrackView::TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent) :
         QWidget(parent),
         m_scale(1.0),
         m_projectTracks(0),
-        m_doc(doc)
+        m_doc(doc),
+        m_verticalZoom(1)
 {
 
     m_view.setupUi(this);
@@ -59,6 +60,28 @@ TrackView::TrackView(KdenliveDoc *doc, QWidget *parent) :
     m_view.ruler_frame->setLayout(layout);
     layout->addWidget(m_ruler);
 
+
+    QHBoxLayout *sizeLayout = new QHBoxLayout;
+    sizeLayout->setContentsMargins(0, 0, 0, 0);
+    sizeLayout->setSpacing(0);
+    m_view.size_frame->setLayout(sizeLayout);
+
+    QString style1 = "QToolButton {border-style: none;margin: 0px 3px;padding: 0px;} QToolButton:pressed:hover { background-color: rgba(224, 224, 0, 100); border-style: inset; border:1px solid #cc6666;border-radius: 3px;} QToolButton:hover { background-color: rgba(255, 255, 255, 100); border-style: inset; border:1px solid #cc6666;border-radius: 3px;}";
+
+    QToolButton *butSmall = new QToolButton(this);
+    butSmall->setIcon(KIcon("kdenlive-zoom-small"));
+    butSmall->setToolTip(i18n("Smaller tracks"));
+    connect(butSmall, SIGNAL(clicked()), this, SLOT(slotVerticalZoomDown()));
+    sizeLayout->addWidget(butSmall);
+
+    QToolButton *butLarge = new QToolButton(this);
+    butLarge->setIcon(KIcon("kdenlive-zoom-large"));
+    butLarge->setToolTip(i18n("Bigger tracks"));
+    connect(butLarge, SIGNAL(clicked()), this, SLOT(slotVerticalZoomUp()));
+    sizeLayout->addWidget(butLarge);
+    m_view.size_frame->setStyleSheet(style1);
+
+
     QHBoxLayout *tracksLayout = new QHBoxLayout;
     tracksLayout->setContentsMargins(0, 0, 0, 0);
     tracksLayout->setSpacing(0);
@@ -80,17 +103,23 @@ TrackView::TrackView(KdenliveDoc *doc, QWidget *parent) :
     connect(m_trackview, SIGNAL(trackHeightChanged()), this, SLOT(slotRebuildTrackHeaders()));
 
     parseDocument(m_doc->toXml());
-    m_doc->setSceneList();
+    int error = m_doc->setSceneList();
+    if (error == -1) *ok = false;
+    else *ok = true;
     connect(m_trackview, SIGNAL(cursorMoved(int, int)), m_ruler, SLOT(slotCursorMoved(int, int)));
     connect(m_trackview->horizontalScrollBar(), SIGNAL(valueChanged(int)), m_ruler, SLOT(slotMoveRuler(int)));
     connect(m_trackview, SIGNAL(mousePosition(int)), this, SIGNAL(mousePosition(int)));
-    connect(m_trackview, SIGNAL(transitionItemSelected(Transition*, bool)), this, SLOT(slotTransitionItemSelected(Transition*, bool)));
     connect(m_trackview, SIGNAL(doTrackLock(int, bool)), this, SLOT(slotChangeTrackLock(int, bool)));
 
-    slotChangeZoom(m_doc->zoom());
+    slotChangeZoom(m_doc->zoom().x(), m_doc->zoom().y());
     slotSetZone(m_doc->zone());
 }
 
+TrackView::~TrackView()
+{
+    delete m_ruler;
+    delete m_trackview;
+}
 
 int TrackView::duration() const
 {
@@ -117,11 +146,6 @@ void TrackView::slotSetZone(QPoint p)
     m_ruler->setZone(p);
 }
 
-void TrackView::slotTransitionItemSelected(Transition *t, bool update)
-{
-    emit transitionItemSelected(t, update);
-}
-
 void TrackView::setDuration(int dur)
 {
     m_trackview->setDuration(dur);
@@ -209,7 +233,7 @@ void TrackView::parseDocument(QDomDocument doc)
 
             trackduration = slotAddProjectTrack(pos, p, m_doc->isTrackLocked(i - 1));
             pos--;
-            //kDebug() << " PRO DUR: " << trackduration << ", TRACK DUR: " << duration;
+            //kDebug() << " PRO DUR: " << trackduration << ", TRACK DUR: " << duration;
             if (trackduration > duration) duration = trackduration;
         } else {
             // background black track
@@ -239,18 +263,20 @@ void TrackView::parseDocument(QDomDocument doc)
         bool forceTrack = false;
         QString mlt_geometry;
         QString mlt_service;
+        QString transitionId;
         for (int k = 0; k < transitionparams.count(); k++) {
             p = transitionparams.item(k).toElement();
             if (!p.isNull()) {
                 QString paramName = p.attribute("name");
-                // do not add audio mixing transitions
+                // do not add audio mixing transitions
                 if (paramName == "internal_added" && p.text() == "237") {
                     transitionAdd = false;
-                    //kDebug() << "//  TRANSITRION " << i << " IS NOT VALID (INTERN ADDED)";
+                    //kDebug() << "//  TRANSITRION " << i << " IS NOT VALID (INTERN ADDED)";
                     //break;
                 } else if (paramName == "a_track") a_track = p.text().toInt();
                 else if (paramName == "b_track") b_track = p.text().toInt();
                 else if (paramName == "mlt_service") mlt_service = p.text();
+                else if (paramName == "kdenlive_id") transitionId = p.text();
                 else if (paramName == "geometry") mlt_geometry = p.text();
                 else if (paramName == "automatic" && p.text() == "1") isAutomatic = true;
                 else if (paramName == "force_track" && p.text() == "1") forceTrack = true;
@@ -259,8 +285,7 @@ void TrackView::parseDocument(QDomDocument doc)
         if (transitionAdd || mlt_service != "mix") {
             // Transition should be added to the scene
             ItemInfo transitionInfo;
-            QString transitionId;
-            if (mlt_service == "composite") {
+            if (mlt_service == "composite" && transitionId.isEmpty()) {
                 // When adding composite transition, check if it is a wipe transition
                 if (mlt_geometry.count(';') == 1) {
                     mlt_geometry.remove(QChar('%'), Qt::CaseInsensitive);
@@ -282,7 +307,7 @@ void TrackView::parseDocument(QDomDocument doc)
                             break;
                         }
                     }
-                    if (isWipeTransition) transitionId = "wipe";
+                    if (isWipeTransition) transitionId = "slide";
                 }
             }
             QDomElement base = MainWindow::transitions.getEffectByTag(mlt_service, transitionId).cloneNode().toElement();
@@ -348,9 +373,14 @@ void TrackView::parseDocument(QDomDocument doc)
     // Rebuild groups
     QDomNodeList groups = doc.elementsByTagName("group");
     m_trackview->loadGroups(groups);
-
     m_trackview->setDuration(duration);
     kDebug() << "///////////  TOTAL PROJECT DURATION: " << duration;
+
+    // Remove Kdenlive extra info from xml doc before sending it to MLT
+    QDomElement mlt = doc.firstChildElement("mlt");
+    QDomElement infoXml = mlt.firstChildElement("kdenlivedoc");
+    mlt.removeChild(infoXml);
+
     slotRebuildTrackHeaders();
     if (!m_documentErrors.isNull()) KMessageBox::sorry(this, m_documentErrors);
     //m_trackview->setCursorPos(cursorPos);
@@ -372,12 +402,21 @@ void TrackView::moveCursorPos(int pos)
     m_trackview->setCursorPos(pos, false);
 }
 
-void TrackView::slotChangeZoom(int factor)
+void TrackView::slotChangeZoom(int horizontal, int vertical)
 {
-    m_doc->setZoom(factor);
-    m_ruler->setPixelPerMark(factor);
-    m_scale = (double) FRAME_SIZE / m_ruler->comboScale[factor]; // m_ruler->comboScale[m_currentZoom] /
-    m_trackview->setScale(m_scale);
+    m_ruler->setPixelPerMark(horizontal);
+    m_scale = (double) FRAME_SIZE / m_ruler->comboScale[horizontal]; // m_ruler->comboScale[m_currentZoom] /
+
+    if (vertical == -1) {
+        // user called zoom
+        m_doc->setZoom(horizontal, m_verticalZoom);
+        m_trackview->setScale(m_scale, m_scene->scale().y());
+    } else {
+        m_verticalZoom = vertical;
+        if (m_verticalZoom == 0) m_trackview->setScale(m_scale, 0.5);
+        else m_trackview->setScale(m_scale, m_verticalZoom);
+        adjustTrackHeaders();
+    }
 }
 
 int TrackView::fitZoom() const
@@ -402,11 +441,15 @@ void TrackView::refresh()
 void TrackView::slotRebuildTrackHeaders()
 {
     QList <TrackInfo> list = m_doc->tracksList();
-    QList<HeaderTrack *> widgets = findChildren<HeaderTrack *>();
-    qDeleteAll(widgets);
+    QLayoutItem *child;
+    while ((child = m_headersLayout->takeAt(0)) != 0) {
+        if (child->widget()) delete child->widget();
+        delete child;
+    }
     int max = list.count();
+    int height = KdenliveSettings::trackheight() * m_scene->scale().y();
     for (int i = 0; i < max; i++) {
-        HeaderTrack *header = new HeaderTrack(i, list.at(max - i - 1), this);
+        HeaderTrack *header = new HeaderTrack(i, list.at(max - i - 1), height, this);
         connect(header, SIGNAL(switchTrackVideo(int)), m_trackview, SLOT(slotSwitchTrackVideo(int)));
         connect(header, SIGNAL(switchTrackAudio(int)), m_trackview, SLOT(slotSwitchTrackAudio(int)));
         connect(header, SIGNAL(switchTrackLock(int)), m_trackview, SLOT(slotSwitchTrackLock(int)));
@@ -416,10 +459,19 @@ void TrackView::slotRebuildTrackHeaders()
         connect(header, SIGNAL(changeTrack(int)), this, SIGNAL(changeTrack(int)));
         m_headersLayout->addWidget(header);
     }
-    m_view.headers_container->adjustSize();
 }
 
 
+void TrackView::adjustTrackHeaders()
+{
+    int height = KdenliveSettings::trackheight() * m_scene->scale().y();
+    QLayoutItem *child;
+    for (int i = 0; i < m_headersLayout->count(); i++) {
+        child = m_headersLayout->itemAt(i);
+        if (child->widget())(static_cast <HeaderTrack *>(child->widget()))->adjustSize(height);
+    }
+}
+
 int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
 {
     // parse track
@@ -436,7 +488,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
             // Found a clip
             int in = elem.attribute("in").toInt();
             int out = elem.attribute("out").toInt();
-            if (in > out || in == out || m_invalidProducers.contains(elem.attribute("producer"))) {
+            if (in > out || /*in == out ||*/ m_invalidProducers.contains(elem.attribute("producer"))) {
                 m_documentErrors.append(i18n("Invalid clip removed from track %1 at %2\n", ix, position));
                 xml.removeChild(children.at(nodeindex));
                 nodeindex--;
@@ -451,14 +503,14 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
             } else id = id.section('_', 0, 0);
             DocClipBase *clip = m_doc->clipManager()->getClipById(id);
             if (clip == NULL) {
-                // The clip in playlist was not listed in the kdenlive producers,
+                // The clip in playlist was not listed in the kdenlive producers,
                 // something went wrong, repair required.
                 kWarning() << "CANNOT INSERT CLIP " << id;
 
                 clip = getMissingProducer(id);
                 if (!clip) {
                     // We cannot find the producer, something is really wrong, add
-                    // placeholder color clip
+                    // placeholder color clip
                     QDomDocument doc;
                     QDomElement producerXml = doc.createElement("producer");
                     doc.appendChild(producerXml);
@@ -487,7 +539,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                 clipinfo.endPos = clipinfo.startPos + GenTime(out - in + 1, m_doc->fps());
                 clipinfo.cropStart = GenTime(in, m_doc->fps());
                 clipinfo.track = ix;
-                //kDebug() << "// INSERTING CLIP: " << in << "x" << out << ", track: " << ix << ", ID: " << id << ", SCALE: " << m_scale << ", FPS: " << m_doc->fps();
+                //kDebug() << "// INSERTING CLIP: " << in << "x" << out << ", track: " << ix << ", ID: " << id << ", SCALE: " << m_scale << ", FPS: " << m_doc->fps();
                 ClipItem *item = new ClipItem(clip, clipinfo, m_doc->fps(), speed, false);
                 if (idString.endsWith("_video")) item->setVideoOnly(true);
                 else if (idString.endsWith("_audio")) item->setAudioOnly(true);
@@ -695,8 +747,8 @@ DocClipBase *TrackView::getMissingProducer(const QString id) const
             break;
         }
     }
-    // prepend westley document root if no path in clip resource and not a color clip
-    if (!resource.contains('/') && !resource.startsWith("0x")) resource.prepend(docRoot);
+    // prepend MLT XML document root if no path in clip resource and not a color clip
+    if (!resource.startsWith('/') && !resource.startsWith("0x")) resource.prepend(docRoot);
     DocClipBase *missingClip = NULL;
     if (!resource.isEmpty())
         missingClip = m_doc->clipManager()->getClipByResource(resource);
@@ -729,5 +781,28 @@ void TrackView::slotChangeTrackLock(int ix, bool lock)
     widgets.at(ix)->setLock(lock);
 }
 
+void TrackView::slotVerticalZoomDown()
+{
+    if (m_verticalZoom == 0) return;
+    m_verticalZoom--;
+    m_doc->setZoom(m_doc->zoom().x(), m_verticalZoom);
+    if (m_verticalZoom == 0) m_trackview->setScale(m_scene->scale().x(), 0.5);
+    else m_trackview->setScale(m_scene->scale().x(), 1);
+    adjustTrackHeaders();
+    /*KdenliveSettings::setTrackheight(KdenliveSettings::trackheight() / 2);
+    m_trackview->checkTrackHeight(false);*/
+}
+
+void TrackView::slotVerticalZoomUp()
+{
+    if (m_verticalZoom == 2) return;
+    m_verticalZoom++;
+    m_doc->setZoom(m_doc->zoom().x(), m_verticalZoom);
+    /*KdenliveSettings::setTrackheight(KdenliveSettings::trackheight() * 2);
+    m_trackview->checkTrackHeight(false);*/
+    if (m_verticalZoom == 2) m_trackview->setScale(m_scene->scale().x(), 2);
+    else m_trackview->setScale(m_scene->scale().x(), 1);
+    adjustTrackHeaders();
+}
 
 #include "trackview.moc"
