@@ -45,8 +45,8 @@ class TrackView : public QWidget
     Q_OBJECT
 
 public:
-    explicit TrackView(KdenliveDoc *doc, QWidget *parent = 0);
-
+    explicit TrackView(KdenliveDoc *doc, bool *ok, QWidget *parent = 0);
+    virtual ~ TrackView();
     void setEditMode(const QString & editMode);
     const QString & editMode() const;
     QGraphicsScene *projectScene();
@@ -61,7 +61,7 @@ public:
 
 public slots:
     void slotDeleteClip(const QString &clipId);
-    void slotChangeZoom(int factor);
+    void slotChangeZoom(int horizontal, int vertical = -1);
     void setDuration(int dur);
     void slotSetZone(QPoint p);
 
@@ -76,23 +76,25 @@ private:
     CustomTrackScene *m_scene;
 
     KdenliveDoc *m_doc;
+    int m_verticalZoom;
     QVBoxLayout *m_headersLayout;
     QString m_documentErrors;
     void parseDocument(QDomDocument doc);
     int slotAddProjectTrack(int ix, QDomElement xml, bool locked);
     DocClipBase *getMissingProducer(const QString id) const;
+    void adjustTrackHeaders();
 
 private slots:
     void setCursorPos(int pos);
     void moveCursorPos(int pos);
-    void slotTransitionItemSelected(Transition*, bool update);
     void slotRebuildTrackHeaders();
     void slotChangeTrackLock(int ix, bool lock);
+    void slotVerticalZoomDown();
+    void slotVerticalZoomUp();
 
 signals:
     void mousePosition(int);
     void cursorMoved();
-    void transitionItemSelected(Transition*, bool);
     void zoneMoved(int, int);
     void insertTrack(int);
     void deleteTrack(int);
