@@ -34,23 +34,23 @@
 Transition::Transition(const ItemInfo info, int transitiontrack, double fps, QDomElement params, bool automaticTransition) :
         AbstractClipItem(info, QRectF(), fps),
         m_forceTransitionTrack(false),
-        m_automaticTransition(automaticTransition)
+        m_automaticTransition(automaticTransition),
+        m_secondClip(NULL),
+        m_transitionTrack(transitiontrack)
 {
-    setZValue(2);
+    setZValue(3);
     setRect(0, 0, (info.endPos - info.startPos).frames(fps) - 0.02, (qreal)(KdenliveSettings::trackheight() / 3 * 2 - 1));
     setPos(info.startPos.frames(fps), (qreal)(info.track * KdenliveSettings::trackheight() + KdenliveSettings::trackheight() / 3 * 2));
 
-    m_transitionTrack = transitiontrack;
-    m_secondClip = NULL;
     m_cropStart = GenTime();
-    m_maxDuration = GenTime(10000, fps);
+    m_maxDuration = GenTime(600);
 
     if (m_automaticTransition) setBrush(QColor(200, 200, 50, 100));
     else setBrush(QColor(200, 100, 50, 100));
 
     //m_referenceClip = clipa;
     if (params.isNull()) {
-        m_parameters = MainWindow::transitions.getEffectByName("Luma").cloneNode().toElement();
+        m_parameters = MainWindow::transitions.getEffectByTag("luma", "dissolve").cloneNode().toElement();
     } else {
         m_parameters = params;
     }
@@ -268,7 +268,7 @@ OPERATIONTYPE Transition::operationMode(QPointF pos)
 {
     if (isItemLocked()) return NONE;
 
-    const double scale = projectScene()->scale();
+    const double scale = projectScene()->scale().x();
     double maximumOffset = 6 / scale;
 
     QRectF rect = sceneBoundingRect();
@@ -323,14 +323,13 @@ QDomElement Transition::toXML()
         m_parameters.setAttribute("clipb_starttime", m_secondClip->startPos().frames(m_referenceClip->fps()));
         m_parameters.setAttribute("clipb_track", transitionEndTrack());
     }
-
     return m_parameters;
 }
 
 bool Transition::hasGeometry()
 {
     QDomNodeList namenode = m_parameters.elementsByTagName("parameter");
-    for (int i = 0;i < namenode.count() ;i++) {
+    for (int i = 0; i < namenode.count() ; i++) {
         QDomElement pa = namenode.item(i).toElement();
         if (pa.attribute("type") == "geometry") return true;
     }
